/**
 * Scriptable iOS Type Definitions
 *
 * @file Auto-generated abstract class definitions for Scriptable iOS
 * @source @types/scriptable-ios@1.7.7
 * @module scriptable-abstract
 * @generated 2025-01-12T05:02:47.284Z
 * @license MIT
 */
/**
 * Base abstract class with shared core functionality.
 * Provides common methods for property access and method invocation.
 */
type ScriptableConstructor<T extends object = object, Instance extends ScriptableBase<T> = ScriptableBase<T>> = {
    new (...args: any[]): Instance;
    readonly type: 'class' | 'variable';
    readonly identifier: string;
};
declare abstract class ScriptableBase<T extends object> {
    /**
     * The type of the scriptable implementation.
     */
    static readonly type: 'class' | 'variable';
    /**
     * The identifier name in the target system.
     */
    static readonly identifier: string;
    private static readonly states;
    private frozenState?;
    constructor(initialState?: Partial<T>);
    get state(): Readonly<T>;
    setState<K extends keyof T>(state: Pick<T, K> | Partial<T> | ((prevState: Readonly<T>) => Pick<T, K>)): this;
    protected get internalState(): T;
    protected set internalState(value: T);
    protected updateState(updates: Partial<T>): void;
    protected invokeMethod<R>(method: string, _args: unknown[]): R;
    protected static invokeStaticMethod<R>(method: string, _args: unknown[]): R;
}
/**
 * Base class for objects.
 * Provides implementation for class-based scriptable objects.
 */
declare abstract class ScriptableClass<T extends object> extends ScriptableBase<T> {
    static readonly type = "class";
}
/**
 * Base class for global variables.
 * Provides implementation for global variable access and manipulation.
 */
declare abstract class ScriptableVariable<T extends object> extends ScriptableBase<T> {
    static readonly type = "variable";
    protected static _instance?: ScriptableVariable<any>;
    constructor(initialState?: Partial<T>);
    static get instance(): ScriptableVariable<any>;
}
interface AlertState {
    title: string;
    message: string;
}
declare class AbsAlert<S extends AlertState = AlertState> extends ScriptableClass<S> implements Alert {
    static readonly identifier = "Alert";
    get title(): string;
    set title(value: string);
    get message(): string;
    set message(value: string);
    /**
       * _Adds an action to the alert._
       *
       * Adds an action button to the alert. To check if an action was selected, you should use the first parameter provided when the promise returned by presentAlert() and presentSheet()
       * is resolved.
       * @param title - Title of the action.
       * @see https://docs.scriptable.app/alert/#-addaction
       */
    addAction(title: string): void;
    /**
       * _Adds a destructive action to the alert._
       *
       * Destructive action titles have a red text color, signaling that the action may modify or delete data.
       * @param title - Title of the action.
       * @see https://docs.scriptable.app/alert/#-adddestructiveaction
       */
    addDestructiveAction(title: string): void;
    /**
       * _Adds a cancel action to the alert._
       *
       * Adds a cancel action to the alert. When a cancel action is selected, the index provided by presentAlert() or presentSheet() will always be -1. Please note that when running on the
       * iPad and presenting using presentSheet(), the action will not be shown in the list of actions. The operation is cancelled by tapping outside the sheet.
       *
       * An alert can only contain a single cancel action. Attempting to add more cancel actions will remove any previously added cancel actions.
       * @param title - Title of the action.
       * @see https://docs.scriptable.app/alert/#-addcancelaction
       */
    addCancelAction(title: string): void;
    /**
       * _Adds a text field prompting for user input._
       *
       * Adds a text field to the alert controller prompting for user input. Retrieve the value for the text field using textFieldValue() and supply the index of the text field. Indices for
       * text fields are assigned in the same order as they are added to the alert starting at 0.
       *
       * Text fields are not supported when using the sheet presentation.
       * @param placeholder - Optional placeholder that will be displayed when the text field is empty.
       * @param text - Optional default value for the text field.
       * @see https://docs.scriptable.app/alert/#-addtextfield
       */
    addTextField(placeholder?: string, text?: string): TextField;
    /**
       * _Adds a secure text field prompting for user input._
       *
       * Adds a secure text field to the alert controller prompting for user input. Values entered into a secure text field will be hidden behind dots. Retrieve the value for the text field
       * using textFieldValue() and supply the index of the text field. Indices for text fields are assigned in the same order as they are added to the alert starting at 0.
       * @param placeholder - Optional placeholder that will be displayed when the text field is empty.
       * @param text - Optional default value for the text field.
       * @see https://docs.scriptable.app/alert/#-addsecuretextfield
       */
    addSecureTextField(placeholder?: string, text?: string): TextField;
    /**
       * _Retrieves value of a text field._
       *
       * Retrieves the value of a text field added using addTextField() or addSecureTextField(). Indices for text fields are assigned in the same order as they are added to the alert
       * starting at 0.
       * @param index - Index of text field to retrieve for value.
       * @see https://docs.scriptable.app/alert/#-textfieldvalue
       */
    textFieldValue(index: number): string;
    /**
       * _Presents the alert modally._
       *
       * This is a shorthand for presentAlert().
       * @see https://docs.scriptable.app/alert/#-present
       */
    present(): Promise<number>;
    /**
       * _Presents the alert modally._
       * @see https://docs.scriptable.app/alert/#-presentalert
       */
    presentAlert(): Promise<number>;
    /**
       * _Presents the alert as a sheet._
       * @see https://docs.scriptable.app/alert/#-presentsheet
       */
    presentSheet(): Promise<number>;
}
interface CalendarState {
    identifier: string;
    title: string;
    isSubscribed: boolean;
    allowsContentModifications: boolean;
    color: Color;
}
declare class AbsCalendar<S extends CalendarState = CalendarState> extends ScriptableClass<S> implements Calendar {
    static readonly identifier = "Calendar";
    /**
       * _Fetches calendars for reminders._
       *
       * A calendar can only hold either reminders or events. Call this function to fetch all calendars that can hold reminders.
       * @see https://docs.scriptable.app/calendar/#forreminders
       */
    static forReminders(): Promise<Calendar[]>;
    /**
       * _Fetches calendars for events._
       *
       * A calendar can only hold either reminders or events. Call this function to fetch all calendars that can hold events.
       * @see https://docs.scriptable.app/calendar/#forevents
       */
    static forEvents(): Promise<Calendar[]>;
    /**
       * _Fetches a calendar that holds reminders._
       * @param title - Title of calendar.
       * @see https://docs.scriptable.app/calendar/#forremindersbytitle
       */
    static forRemindersByTitle(title: string): Promise<Calendar>;
    /**
       * _Fetches a calendar that holds events._
       * @param title - Title of calendar.
       * @see https://docs.scriptable.app/calendar/#foreventsbytitle
       */
    static forEventsByTitle(title: string): Promise<Calendar>;
    /**
       * _Create a new calendar that holds reminders._
       *
       * This will create a new list for reminders in the Reminders app. The list is automatically saved so there is no need to call `save()` after creating the list.
       * @see https://docs.scriptable.app/calendar/#createforreminders
       */
    static createForReminders(title: string): Promise<Calendar>;
    /**
       * _Find or create a new calendar that holds reminders._
       *
       * This will attempt to find a calendar for reminders with the specified name. If no calendar is found, a new calendar is created and the calendar will appear as a reminder list in
       * the Reminders app. If multiple calendars are found for the specified name, the first one will be returned. The list is automatically saved so there is no need to call `save()` in
       * the case the list was created.
       * @see https://docs.scriptable.app/calendar/#findorcreateforreminders
       */
    static findOrCreateForReminders(title: string): Promise<Calendar>;
    /**
       * _Default calendar for reminders._
       *
       * A calendar can only hold either reminders or events. Call this function to get the default calendar that can hold reminders.
       * @see https://docs.scriptable.app/calendar/#defaultforreminders
       */
    static defaultForReminders(): Promise<Calendar>;
    /**
       * _Default calendar for events._
       *
       * A calendar can only hold either reminders or events. Call this function to get the default calendar that can hold events.
       * @see https://docs.scriptable.app/calendar/#defaultforevents
       */
    static defaultForEvents(): Promise<Calendar>;
    /**
       * _Presents a view for picking calendars._
       * @param allowMultiple - Whether to allow picking multiple calenders. Defaults to false.
       * @see https://docs.scriptable.app/calendar/#presentpicker
       */
    static presentPicker(allowMultiple?: boolean): Promise<Calendar[]>;
    get identifier(): string;
    set identifier(value: string);
    get title(): string;
    set title(value: string);
    get isSubscribed(): boolean;
    set isSubscribed(value: boolean);
    get allowsContentModifications(): boolean;
    set allowsContentModifications(value: boolean);
    get color(): Color;
    set color(value: Color);
    /**
       * _Checks if the calendar supports availability._
       *
       * The following values are supported:
       *
       * *   busy
       * *   free
       * *   tentative
       * *   unavailable
       *
       * Not all calendars support all of these availabilities and some calendars may not support availability at all. Use this function to check if the calendar supports a specific
       * availability.
       * @param availability - Availability to check against.
       * @see https://docs.scriptable.app/calendar/#-supportsavailability
       */
    supportsAvailability(availability: "busy" | "free" | "tentative" | "unavailable"): boolean;
    /**
       * _Saves calendar._
       *
       * Saves changes to the calendar.
       * @see https://docs.scriptable.app/calendar/#-save
       */
    save(): void;
    /**
       * _Removes calendar._
       *
       * The calendar is removed immediately. This cannot be undone.
       * @see https://docs.scriptable.app/calendar/#-remove
       */
    remove(): void;
}
interface CalendarEventState {
    identifier: string;
    title: string;
    location: string;
    notes: string;
    startDate: Date;
    endDate: Date;
    isAllDay: boolean;
    attendees: CalendarEvent.Attendees[];
    availability: "busy" | "free" | "tentative" | "unavailable";
    timeZone: string;
    calendar: Calendar;
}
declare class AbsCalendarEvent<S extends CalendarEventState = CalendarEventState> extends ScriptableClass<S> implements CalendarEvent {
    static readonly identifier = "CalendarEvent";
    /**
       * _Presents a view for creating a calendar event._
       *
       * The presented view supports editing various attributes of the event, including title, location, dates, recurrence and alerts.
       * @see https://docs.scriptable.app/calendarevent/#presentcreate
       */
    static presentCreate(): Promise<CalendarEvent>;
    /**
       * _Events occurring today._
       * @param calendars - Calendars to fetch events for. Defaults to all calendars.
       * @see https://docs.scriptable.app/calendarevent/#today
       */
    static today(calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
       * _Events occurring tomorrow._
       * @param calendars - Calendars to fetch events for. Defaults to all calendars.
       * @see https://docs.scriptable.app/calendarevent/#tomorrow
       */
    static tomorrow(calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
       * _Events that occurred yesterday._
       * @param calendars - Calendars to fetch events for. Defaults to all calendars.
       * @see https://docs.scriptable.app/calendarevent/#yesterday
       */
    static yesterday(calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
       * _Events that occur this week._
       * @param calendars - Calendars to fetch events for. Defaults to all calendars.
       * @see https://docs.scriptable.app/calendarevent/#thisweek
       */
    static thisWeek(calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
       * _Events that occur next week._
       * @param calendars - Calendars to fetch events for. Defaults to all calendars.
       * @see https://docs.scriptable.app/calendarevent/#nextweek
       */
    static nextWeek(calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
       * _Events that occurred last week._
       * @param calendars - Calendars to fetch events for. Defaults to all calendars.
       * @see https://docs.scriptable.app/calendarevent/#lastweek
       */
    static lastWeek(calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
       * _Events that occurs between two dates._
       * @param startDate - Start date to fetch events for.
       * @param endDate - End date to fetch events for.
       * @param calendars - Calendars to fetch events for. Defaults to all calendars.
       * @see https://docs.scriptable.app/calendarevent/#between
       */
    static between(startDate: Date, endDate: Date, calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    get identifier(): string;
    set identifier(value: string);
    get title(): string;
    set title(value: string);
    get location(): string;
    set location(value: string);
    get notes(): string;
    set notes(value: string);
    get startDate(): Date;
    set startDate(value: Date);
    get endDate(): Date;
    set endDate(value: Date);
    get isAllDay(): boolean;
    set isAllDay(value: boolean);
    get attendees(): CalendarEvent.Attendees[];
    set attendees(value: CalendarEvent.Attendees[]);
    get availability(): "busy" | "free" | "tentative" | "unavailable";
    set availability(value: "busy" | "free" | "tentative" | "unavailable");
    get timeZone(): string;
    set timeZone(value: string);
    get calendar(): Calendar;
    set calendar(value: Calendar);
    /**
       * _Adds a recurrence rule._
       *
       * Recurrence rules specify when the event or reminder should be repeated. See the documentation of RecurrenceRule for more information on creating rules.
       * @param recurrenceRule - Recurrence rule to add to the reminder.
       * @see https://docs.scriptable.app/calendarevent/#-addrecurrencerule
       */
    addRecurrenceRule(recurrenceRule: RecurrenceRule): void;
    /**
       * _Removes all recurrence rules._
       * @see https://docs.scriptable.app/calendarevent/#-removeallrecurrencerules
       */
    removeAllRecurrenceRules(): void;
    /**
       * _Saves event._
       *
       * Saves changes to an event, inserting it into the calendar if it is newly created.
       * @see https://docs.scriptable.app/calendarevent/#-save
       */
    save(): void;
    /**
       * _Removes event from calendar._
       * @see https://docs.scriptable.app/calendarevent/#-remove
       */
    remove(): void;
    /**
       * _Presents a view for editing the calendar event._
       *
       * The presented view supports editing various attributes of the event, including title, location, dates, recurrence and alerts.
       * @see https://docs.scriptable.app/calendarevent/#-presentedit
       */
    presentEdit(): Promise<CalendarEvent>;
}
interface CallbackURLState {
}
declare class AbsCallbackURL<T extends string, S extends CallbackURLState = CallbackURLState> extends ScriptableClass<S> implements CallbackURL<T> {
    static readonly identifier = "CallbackURL";
    /**
       * _Construct CallbackURL._
       *
       * Appends a key/value pair to the base URL as a query parameter. The name and value are automatically encoded. Do not add the x-callback-url paramters, i.e. x-source, x-success,
       * x-error and x-cancel as Scriptable will add those.
       * @param name - Name of the query parameter to add.
       * @param value - Value of the query parameter to add.
       * @see https://docs.scriptable.app/callbackurl/#-addparameter
       */
    addParameter(name: string, value: string): void;
    /**
       * _Opens the callback URL._
       *
       * Opens the target app and waits for the target app to perform the action. The returned promise contains the query parameters supplied by the target app when it invokes the callback.
       * If the action failed in the target app or the action was cancelled, the promise will be rejected. The promise is also rejected if the action times out because the target app did
       * not invoke the callback.
       * @see https://docs.scriptable.app/callbackurl/#-open
       */
    open(): Promise<T extends `shortcuts://x-callback-url/${string}` ? {
        result: string | number | boolean | null;
    } : Record<string, string | number | boolean | null>>;
    /**
       * _Creates the callback URL._
       *
       * Creates a callback URL with the specified base URL and query parameters.
       * @see https://docs.scriptable.app/callbackurl/#-geturl
       */
    getURL(): string;
}
interface ColorState {
    hex: string;
    red: number;
    green: number;
    blue: number;
    alpha: number;
}
declare class AbsColor<S extends ColorState = ColorState> extends ScriptableClass<S> implements Color {
    static readonly identifier = "Color";
    /**
       * _Constructs a black color._
       * @see https://docs.scriptable.app/color/#black
       */
    static black(): Color;
    /**
       * _Constructs a dark gray color._
       * @see https://docs.scriptable.app/color/#darkgray
       */
    static darkGray(): Color;
    /**
       * _Constructs a light gray color._
       * @see https://docs.scriptable.app/color/#lightgray
       */
    static lightGray(): Color;
    /**
       * _Constructs a white color._
       * @see https://docs.scriptable.app/color/#white
       */
    static white(): Color;
    /**
       * _Constructs a gray color._
       * @see https://docs.scriptable.app/color/#gray
       */
    static gray(): Color;
    /**
       * _Constructs a red color._
       * @see https://docs.scriptable.app/color/#red
       */
    static red(): Color;
    /**
       * _Constructs a green color._
       * @see https://docs.scriptable.app/color/#green
       */
    static green(): Color;
    /**
       * _Constructs a blue color._
       * @see https://docs.scriptable.app/color/#blue
       */
    static blue(): Color;
    /**
       * _Constructs a cyan color._
       * @see https://docs.scriptable.app/color/#cyan
       */
    static cyan(): Color;
    /**
       * _Constructs a yellow color._
       * @see https://docs.scriptable.app/color/#yellow
       */
    static yellow(): Color;
    /**
       * _Constructs a magenta color._
       * @see https://docs.scriptable.app/color/#magenta
       */
    static magenta(): Color;
    /**
       * _Constructs a orange color._
       * @see https://docs.scriptable.app/color/#orange
       */
    static orange(): Color;
    /**
       * _Constructs a purple color._
       * @see https://docs.scriptable.app/color/#purple
       */
    static purple(): Color;
    /**
       * _Constructs a brown color._
       * @see https://docs.scriptable.app/color/#brown
       */
    static brown(): Color;
    /**
       * _Constructs a transparent color._
       * @see https://docs.scriptable.app/color/#clear
       */
    static clear(): Color;
    /**
       * _Creates a dynamic color._
       *
       * The dynamic color will use either its light or dark variant depending on the appearance of the system.
       *
       * Dynamic colors are not supported when used with `DrawContext`.
       * @param lightColor - Color used in light appearance.
       * @param darkColor - Color used in dark appearance.
       * @see https://docs.scriptable.app/color/#dynamic
       */
    static dynamic(lightColor: Color, darkColor: Color): Color;
    get hex(): string;
    set hex(value: string);
    get red(): number;
    set red(value: number);
    get green(): number;
    set green(value: number);
    get blue(): number;
    set blue(value: number);
    get alpha(): number;
    set alpha(value: number);
}
interface ContactState {
    identifier: string;
    namePrefix: string;
    givenName: string;
    middleName: string;
    familyName: string;
    nickname: string;
    birthday: Date;
    image: Image;
    emailAddresses: Contact.EmailAddresses[];
    phoneNumbers: Contact.PhoneNumbers[];
    postalAddresses: Contact.PostalAddresses[];
    socialProfiles: Contact.SocialProfiles[];
    note: string;
    urlAddresses: {
        [key: string]: string;
    }[];
    dates: {
        [key: string]: any;
    }[];
    organizationName: string;
    departmentName: string;
    jobTitle: string;
    isNamePrefixAvailable: boolean;
    isGiveNameAvailable: boolean;
    isMiddleNameAvailable: boolean;
    isFamilyNameAvailable: boolean;
    isNicknameAvailable: boolean;
    isBirthdayAvailable: boolean;
    isEmailAddressesAvailable: boolean;
    isPhoneNumbersAvailable: boolean;
    isPostalAddressesAvailable: boolean;
    isSocialProfilesAvailable: boolean;
    isImageAvailable: boolean;
    isNoteAvailable: boolean;
    isURLAddressesAvailable: boolean;
    isOrganizationNameAvailable: boolean;
    isDepartmentNameAvailable: boolean;
    isJobTitleAvailable: boolean;
    isDatesAvailable: boolean;
}
declare class AbsContact<S extends ContactState = ContactState> extends ScriptableClass<S> implements Contact {
    static readonly identifier = "Contact";
    /**
       * _Fetches contacts._
       *
       * Fetches the contacts in the specified containers. A contact can be in only one container.
       * @param containers - Containers to fetch contacts from.
       * @see https://docs.scriptable.app/contact/#all
       */
    static all(containers: readonly ContactsContainer[]): Promise<Contact[]>;
    /**
       * _Fetches contacts in groups._
       *
       * Fetches the contacts in the specified contacts groups. A contact may belong to many groups.
       * @param groups - Groups to fetch contacts from.
       * @see https://docs.scriptable.app/contact/#ingroups
       */
    static inGroups(groups: readonly ContactsGroup[]): Promise<Contact[]>;
    /**
       * _Queues a contact to be added._
       *
       * After you have created a contact, you must queue the contact to be added to the address book and invoke `Contact.persistChanges()` to persist the changes to the address book.
       *
       * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
       * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
       * @param contact - Contact to queue to be added.
       * @param containerIdentifier - Optional. Identifier of container to add the contact to. If null is specified, the contact will be added to the default container.
       * @see https://docs.scriptable.app/contact/#add
       */
    static add(contact: Contact, containerIdentifier?: string): void;
    /**
       * _Queues an update to a contact._
       *
       * After you have updated one or more properties on a contact, you must queue the contact to be updated and invoke `Contact.persistChanges()` to persist the changes to the address
       * book.
       *
       * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
       * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
       * @param contact - Contact to queue to be updated.
       * @see https://docs.scriptable.app/contact/#update
       */
    static update(contact: Contact): void;
    /**
       * _Queues a contact to be deleted._
       *
       * To delete a contact, you must queue the contact for deletion and invoke `Contact.persistChanges()` to persist the changes to the address book.
       *
       * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
       * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
       * @param contact - Contact to queue to be deleted.
       * @see https://docs.scriptable.app/contact/#delete
       */
    static delete(contact: Contact): void;
    /**
       * _Persist queued changes to the address book._
       *
       * Call this function to persist changes queued with `Contact.add()`, `Contact.update()` and `Contact.delete()`.
       *
       * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
       * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
       * @see https://docs.scriptable.app/contact/#persistchanges
       */
    static persistChanges(): Promise<void>;
    get identifier(): string;
    set identifier(value: string);
    get namePrefix(): string;
    set namePrefix(value: string);
    get givenName(): string;
    set givenName(value: string);
    get middleName(): string;
    set middleName(value: string);
    get familyName(): string;
    set familyName(value: string);
    get nickname(): string;
    set nickname(value: string);
    get birthday(): Date;
    set birthday(value: Date);
    get image(): Image;
    set image(value: Image);
    get emailAddresses(): Contact.EmailAddresses[];
    set emailAddresses(value: Contact.EmailAddresses[]);
    get phoneNumbers(): Contact.PhoneNumbers[];
    set phoneNumbers(value: Contact.PhoneNumbers[]);
    get postalAddresses(): Contact.PostalAddresses[];
    set postalAddresses(value: Contact.PostalAddresses[]);
    get socialProfiles(): Contact.SocialProfiles[];
    set socialProfiles(value: Contact.SocialProfiles[]);
    get note(): string;
    set note(value: string);
    get urlAddresses(): {
        [key: string]: string;
    }[];
    set urlAddresses(value: {
        [key: string]: string;
    }[]);
    get dates(): {
        [key: string]: any;
    }[];
    set dates(value: {
        [key: string]: any;
    }[]);
    get organizationName(): string;
    set organizationName(value: string);
    get departmentName(): string;
    set departmentName(value: string);
    get jobTitle(): string;
    set jobTitle(value: string);
    get isNamePrefixAvailable(): boolean;
    set isNamePrefixAvailable(value: boolean);
    get isGiveNameAvailable(): boolean;
    set isGiveNameAvailable(value: boolean);
    get isMiddleNameAvailable(): boolean;
    set isMiddleNameAvailable(value: boolean);
    get isFamilyNameAvailable(): boolean;
    set isFamilyNameAvailable(value: boolean);
    get isNicknameAvailable(): boolean;
    set isNicknameAvailable(value: boolean);
    get isBirthdayAvailable(): boolean;
    set isBirthdayAvailable(value: boolean);
    get isEmailAddressesAvailable(): boolean;
    set isEmailAddressesAvailable(value: boolean);
    get isPhoneNumbersAvailable(): boolean;
    set isPhoneNumbersAvailable(value: boolean);
    get isPostalAddressesAvailable(): boolean;
    set isPostalAddressesAvailable(value: boolean);
    get isSocialProfilesAvailable(): boolean;
    set isSocialProfilesAvailable(value: boolean);
    get isImageAvailable(): boolean;
    set isImageAvailable(value: boolean);
    get isNoteAvailable(): boolean;
    set isNoteAvailable(value: boolean);
    get isURLAddressesAvailable(): boolean;
    set isURLAddressesAvailable(value: boolean);
    get isOrganizationNameAvailable(): boolean;
    set isOrganizationNameAvailable(value: boolean);
    get isDepartmentNameAvailable(): boolean;
    set isDepartmentNameAvailable(value: boolean);
    get isJobTitleAvailable(): boolean;
    set isJobTitleAvailable(value: boolean);
    get isDatesAvailable(): boolean;
    set isDatesAvailable(value: boolean);
}
interface ContactsContainerState {
    identifier: string;
    name: string;
}
declare class AbsContactsContainer<S extends ContactsContainerState = ContactsContainerState> extends ScriptableClass<S> implements ContactsContainer {
    static readonly identifier = "ContactsContainer";
    /**
       * _Fetches default contacts container._
       * @see https://docs.scriptable.app/contactscontainer/#default
       */
    static default(): Promise<ContactsContainer>;
    /**
       * _Fetches all contacts containers._
       * @see https://docs.scriptable.app/contactscontainer/#all
       */
    static all(): Promise<ContactsContainer[]>;
    /**
       * _Fetches a contacts container._
       * @param identifier - Identifier of the contacts container to fetch.
       * @see https://docs.scriptable.app/contactscontainer/#withidentifier
       */
    static withIdentifier(identifier: string): Promise<ContactsContainer>;
    get identifier(): string;
    set identifier(value: string);
    get name(): string;
    set name(value: string);
}
interface ContactsGroupState {
    identifier: string;
    name: string;
}
declare class AbsContactsGroup<S extends ContactsGroupState = ContactsGroupState> extends ScriptableClass<S> implements ContactsGroup {
    static readonly identifier = "ContactsGroup";
    /**
       * _Fetches contacts groups._
       *
       * Fetches the contacts groups in the specified containers. A group can be in only one container.
       * @param containers - Container to fetch contacts groups from.
       * @see https://docs.scriptable.app/contactsgroup/#all
       */
    static all(containers: readonly ContactsContainer[]): Promise<ContactsGroup[]>;
    /**
       * _Queues a contacts group to be added._
       *
       * After you have created a group, you must queue the group to be added to the address book and invoke `Contact.persistChanges()` to persist the changes to the address book.
       *
       * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
       * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
       * @param group - Contacts group to queue to be added.
       * @param containerIdentifier - Optional. Identifier of container to add the contacts group to. If null is specified, the group will be added to the default container.
       * @see https://docs.scriptable.app/contactsgroup/#add
       */
    static add(group: ContactsGroup, containerIdentifier?: string): void;
    /**
       * _Queues an update to a contacts group._
       *
       * After you have updated one or more properties on a contacts group, you must queue the group to be updated and invoke `Contact.persistChanges()` to persist the changes to the
       * address book.
       *
       * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
       * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
       * @param group - Contacts group to queue to be updated.
       * @see https://docs.scriptable.app/contactsgroup/#update
       */
    static update(group: ContactsGroup): void;
    /**
       * _Queues a contacts group to be deleted._
       *
       * To delete a contacts group, you must queue the group for deletion and invoke `Contact.persistChanges()` to persist the changes to the address book.
       *
       * For performance reasons, it is best to batch changes to the address book. Therefore you should queue all updates, insertions and removals of contacts and contacts groups to as
       * large batches as possible and then call `Contact.persistChanges()` when you want to persist the changes to the address book.
       * @param group - Contacts group to queue to be deleted.
       * @see https://docs.scriptable.app/contactsgroup/#delete
       */
    static delete(group: ContactsGroup): void;
    get identifier(): string;
    set identifier(value: string);
    get name(): string;
    set name(value: string);
    /**
       * _Adds a contact to the group._
       *
       * In order to persist the change, you should call `Contact.persistChanges()`. It is important that the contact is added to the address book. To add the contact to the address book,
       * you should queue it for insertion using `Contact.add()` before persisting the changes.
       * @param contact - Contact to add to the group.
       * @see https://docs.scriptable.app/contactsgroup/#-addmember
       */
    addMember(contact: Contact): void;
    /**
       * _Removes a contact from the group._
       *
       * In order to persist the change, you should call `Contact.persistChanges()`. It is important that the contact is added to the address book. To add the contact to the address book,
       * you should queue it for insertion using `Contact.add()` before persisting the changes.
       * @param contact - Contact to add to the group.
       * @see https://docs.scriptable.app/contactsgroup/#-removemember
       */
    removeMember(contact: Contact): void;
}
interface DataState {
}
declare class AbsData<S extends DataState = DataState> extends ScriptableClass<S> implements Data {
    static readonly identifier = "Data";
    /**
       * _Creates data from string._
       *
       * The provided string is assumed to be UTF8 encoded. If the string is not UTF8 encoded, the function will return null.
       * @param string - String to create data from.
       * @see https://docs.scriptable.app/data/#fromstring
       */
    static fromString(string: string): Data;
    /**
       * _Reads data from file path._
       *
       * Reads the raw data of the file at the specified file path.
       * @param filePath - Path of file to read data from.
       * @see https://docs.scriptable.app/data/#fromfile
       */
    static fromFile(filePath: string): Data;
    /**
       * _Creates data from base64 encoded string._
       *
       * The supplied string must be base64 encoded otherwise the function will return null.
       * @param base64String - Base64 encoded string to create data from.
       * @see https://docs.scriptable.app/data/#frombase64string
       */
    static fromBase64String(base64String: string): Data;
    /**
       * _Creates data from JPEG image._
       * @param image - JPEG image to convert to data.
       * @see https://docs.scriptable.app/data/#fromjpeg
       */
    static fromJPEG(image: Image): Data;
    /**
       * _Creates data from PNG image._
       * @param image - PNG image to convert to data.
       * @see https://docs.scriptable.app/data/#frompng
       */
    static fromPNG(image: Image): Data;
    /**
       * _Creates data from an array of bytes._
       * @param bytes - Array of bytes to convert to data.
       * @see https://docs.scriptable.app/data/#frombytes
       */
    static fromBytes(bytes: readonly number[]): Data;
    /**
       * _Creates a string from the data._
       *
       * The data is assumed to represent a UTF8 encoded string. If the string is not UTF8 encoded string, the function will return null.
       * @see https://docs.scriptable.app/data/#-torawstring
       */
    toRawString(): string;
    /**
       * _Creates a base64 encoded string._
       *
       * Creates a base64 encoded string from the data.
       * @see https://docs.scriptable.app/data/#-tobase64string
       */
    toBase64String(): string;
    /**
       * _Gets bytes from data._
       * @see https://docs.scriptable.app/data/#-getbytes
       */
    getBytes(): number[];
}
interface DateFormatterState {
    dateFormat: string;
    locale: string;
}
declare class AbsDateFormatter<S extends DateFormatterState = DateFormatterState> extends ScriptableClass<S> implements DateFormatter {
    static readonly identifier = "DateFormatter";
    get dateFormat(): string;
    set dateFormat(value: string);
    get locale(): string;
    set locale(value: string);
    /**
       * _Creates a string from a date._
       * @param date - The date to convert to a string.
       * @see https://docs.scriptable.app/dateformatter/#-string
       */
    string(date: Date): string;
    /**
       * _Creates a date from a string._
       *
       * Uses the date formatters configuration to parse the string into a date. If the string cannot be parsed with the date foramtters configuration, the function will return null.
       * @param str - The string to parse into a date.
       * @see https://docs.scriptable.app/dateformatter/#-date
       */
    date(str: string): Date;
    /**
       * _Use no style for the date._
       *
       * This will remove the date from the formatted string.
       * @see https://docs.scriptable.app/dateformatter/#-usenodatestyle
       */
    useNoDateStyle(): void;
    /**
       * _Use a short style for the date._
       *
       * Dates with a short style are typically numeric only e.g. "08/23/19".
       * @see https://docs.scriptable.app/dateformatter/#-useshortdatestyle
       */
    useShortDateStyle(): void;
    /**
       * _Use a medium style for the date._
       *
       * Dates with a medium style usually includes abbreviations, e.g. "Aug 23, 2019".
       * @see https://docs.scriptable.app/dateformatter/#-usemediumdatestyle
       */
    useMediumDateStyle(): void;
    /**
       * _Use a long style for the date._
       *
       * Dates with a long style usually includes a full text, e.g. "August 23, 2019".
       * @see https://docs.scriptable.app/dateformatter/#-uselongdatestyle
       */
    useLongDateStyle(): void;
    /**
       * _Use a full style for the date._
       *
       * Dates with a full style includes all details, e.g. "Friday, August 23, 2019 AD".
       * @see https://docs.scriptable.app/dateformatter/#-usefulldatestyle
       */
    useFullDateStyle(): void;
    /**
       * _Use no style for the time._
       *
       * This will remove the time from the formatted string.
       * @see https://docs.scriptable.app/dateformatter/#-usenotimestyle
       */
    useNoTimeStyle(): void;
    /**
       * _Use a short style for the time._
       *
       * Times with a short style are typically numeric only but also includes the period for 12-hour clocks, e.g. "7:17 PM".
       * @see https://docs.scriptable.app/dateformatter/#-useshorttimestyle
       */
    useShortTimeStyle(): void;
    /**
       * _Use a short style for the time._
       *
       * Times with a medium style usually includes abbreviations, e.g. "7:16:42 PM".
       * @see https://docs.scriptable.app/dateformatter/#-usemediumtimestyle
       */
    useMediumTimeStyle(): void;
    /**
       * _Use a long style for the time._
       *
       * Times with a long style usually includes a full text, e.g. "7:16:42 PM PST".
       * @see https://docs.scriptable.app/dateformatter/#-uselongtimestyle
       */
    useLongTimeStyle(): void;
    /**
       * _Use a full style for the time._
       *
       * Times with a full style includes all details, e.g. "7:16:42 PM Pacific Standard Time".
       * @see https://docs.scriptable.app/dateformatter/#-usefulltimestyle
       */
    useFullTimeStyle(): void;
}
interface DatePickerState {
    minimumDate: Date;
    maximumDate: Date;
    countdownDuration: number;
    minuteInterval: number;
    initialDate: Date;
}
declare class AbsDatePicker<S extends DatePickerState = DatePickerState> extends ScriptableClass<S> implements DatePicker {
    static readonly identifier = "DatePicker";
    get minimumDate(): Date;
    set minimumDate(value: Date);
    get maximumDate(): Date;
    set maximumDate(value: Date);
    get countdownDuration(): number;
    set countdownDuration(value: number);
    get minuteInterval(): number;
    set minuteInterval(value: number);
    get initialDate(): Date;
    set initialDate(value: Date);
    /**
       * _Presents the date picker displaying hours and minutes._
       *
       * Use the method to pick a time. The date picker will display hours and minutes and, depending on the locale of the device, an AM/PM designation.
       *
       * The returned date will be the current date with the hour and minute set to the selected values. Use the `initialDate` property to set the initially selected date.
       * @see https://docs.scriptable.app/datepicker/#-picktime
       */
    pickTime(): Promise<Date>;
    /**
       * _Presents the date picker displaying day, month and year._
       *
       * Use the method to pick a date. The date picker will display the day, month and year. Use the `initialDate` property to set the initially selected date.
       * @see https://docs.scriptable.app/datepicker/#-pickdate
       */
    pickDate(): Promise<Date>;
    /**
       * _Presents the date picker displaying date and time._
       *
       * Use the method to pick a date and a time. The date picker will display the day, month, year, hour, minutes and, depending on the locale of the device, an AM/PM designation. Use the
       * `initialDate` property to set the initially selected date.
       * @see https://docs.scriptable.app/datepicker/#-pickdateandtime
       */
    pickDateAndTime(): Promise<Date>;
    /**
       * _Presents the date picker for selecting the duration of a countdown._
       *
       * Use the method to pick the duration of a countdown, e.g. a timer. The date picker will display hours and minutes. Use the `countdownDuration` property to set the initially selected
       * duration.
       * @see https://docs.scriptable.app/datepicker/#-pickcountdownduration
       */
    pickCountdownDuration(): Promise<number>;
}
interface DrawContextState {
    size: Size;
    respectScreenScale: boolean;
    opaque: boolean;
}
declare class AbsDrawContext<S extends DrawContextState = DrawContextState> extends ScriptableClass<S> implements DrawContext {
    static readonly identifier = "DrawContext";
    get size(): Size;
    set size(value: Size);
    get respectScreenScale(): boolean;
    set respectScreenScale(value: boolean);
    get opaque(): boolean;
    set opaque(value: boolean);
    /**
       * _Retrieves the image._
       *
       * Call this to retrieve the image you have drawn to the context.
       * @see https://docs.scriptable.app/drawcontext/#-getimage
       */
    getImage(): Image;
    /**
       * _Draws an image in the specified rect._
       *
       * Draws the image in the rectangle. The image will be scaled to fit within the rectangle.
       * @param image - Image to draw.
       * @param rect - Rectangle to draw the image in.
       * @see https://docs.scriptable.app/drawcontext/#-drawimageinrect
       */
    drawImageInRect(image: Image, rect: Rect): void;
    /**
       * _Draws an image at the specified point._
       *
       * Draws the image at the point. The top-left corner of the image will be drawn at the specified point.
       * @param image - Image to draw.
       * @param point - Point at which to draw top-left corner of the image.
       * @see https://docs.scriptable.app/drawcontext/#-drawimageatpoint
       */
    drawImageAtPoint(image: Image, point: Point): void;
    /**
       * _Sets the fill color._
       *
       * Sets the fill color to be used when performing a fill operation. Any fill operation performed afterwards will fill with the specified color until another call to setFillColor is
       * made.
       * @param color - Color to set for filling.
       * @see https://docs.scriptable.app/drawcontext/#-setfillcolor
       */
    setFillColor(color: Color): void;
    /**
       * _Sets the stroke color._
       *
       * Sets the stroke color to be used when performing a stroke operation. Any stroke operation performed afterwards will stroke with the specified color until another call to
       * setStrokeColor is made.
       * @param color - Color to set for stroking.
       * @see https://docs.scriptable.app/drawcontext/#-setstrokecolor
       */
    setStrokeColor(color: Color): void;
    /**
       * _Sets the line width for stroking._
       *
       * Sets the line width to be used when performing a stroke operation.
       * @param width - Line width to use for stroking.
       * @see https://docs.scriptable.app/drawcontext/#-setlinewidth
       */
    setLineWidth(width: number): void;
    /**
       * _Fills a rectangle._
       *
       * Fills the rectangle with the color set when calling setFillColor.
       * @param rect - Rectangle to fill.
       * @see https://docs.scriptable.app/drawcontext/#-fill
       */
    fill(rect: Rect): void;
    /**
       * _Fills a rectangle._
       *
       * Fills the rectangle with the color set when calling setFillColor.
       * @param rect - Rectangle to fill.
       * @see https://docs.scriptable.app/drawcontext/#-fillrect
       */
    fillRect(rect: Rect): void;
    /**
       * _Fills an ellipse._
       *
       * Fills the ellipse that fits within the supplied rectangle with the color set when calling setFillColor.
       * @param rect - Rectangle incapsulating the ellipse to fill.
       * @see https://docs.scriptable.app/drawcontext/#-fillellipse
       */
    fillEllipse(rect: Rect): void;
    /**
       * _Strokes a rectangle._
       *
       * Draws a line around the rectangle using the color set when calling setStrokeColor. The line will have the width set when calling setLineWidth.
       * @param rect - Rectangle to stroke.
       * @see https://docs.scriptable.app/drawcontext/#-stroke
       */
    stroke(rect: Rect): void;
    /**
       * _Strokes a rectangle._
       *
       * Draws a line around the rectangle using the color set when calling setStrokeColor. The line will have the width set when calling setLineWidth.
       * @param rect - Rectangle to stroke.
       * @see https://docs.scriptable.app/drawcontext/#-strokerect
       */
    strokeRect(rect: Rect): void;
    /**
       * _Strokes an ellipse._
       *
       * Draws a line around the ellipse that fits within the supplied rectangle. The line will have the color set when calling setStrokeColor and the width set when calling setLineWidth.
       * @param rect - Rectangle incapsulating the ellipse to stroke.
       * @see https://docs.scriptable.app/drawcontext/#-strokeellipse
       */
    strokeEllipse(rect: Rect): void;
    /**
       * _Adds a path to the context._
       *
       * After adding a path to the context, the path can be stroked or filled by calling strokePath and fillPath. Note that only the path that was added latest will be affected by calls to
       * strokePath and fillPath.
       * @param path - Path to add to the context.
       * @see https://docs.scriptable.app/drawcontext/#-addpath
       */
    addPath(path: Path): void;
    /**
       * _Strokes the path that was added the latest._
       *
       * The path that was added the latest to the context is stroked with the color set using setStrokeColor and the line width set using setLineWidth.
       * @see https://docs.scriptable.app/drawcontext/#-strokepath
       */
    strokePath(): void;
    /**
       * _Fills the path that was added the latest._
       *
       * The path that was latest added to the context is filled with the color set using setFillColor.
       * @see https://docs.scriptable.app/drawcontext/#-fillpath
       */
    fillPath(): void;
    /**
       * _Draws text at a position._
       *
       * Call this to draw a text string to the context. The top-left of the text will be drawn at the specified position.
       * @param text - Text to draw.
       * @param pos - Position to draw the top-left of the text.
       * @see https://docs.scriptable.app/drawcontext/#-drawtext
       */
    drawText(text: string, pos: Point): void;
    /**
       * _Draws text in a rectangle._
       *
       * Call this to draw a text string in a rectangle. Specify how the text should be aligned within the rectangle by calling setTextAlignedLeft, setTextAlignedCenter or
       * setTextAlignedRight before drawing the text.
       * @param text - Text to draw.
       * @param rect - Rectangle to draw text in.
       * @see https://docs.scriptable.app/drawcontext/#-drawtextinrect
       */
    drawTextInRect(text: string, rect: Rect): void;
    /**
       * _Sets the font to use when drawing text._
       *
       * Sets the font to be used when drawing texts to the context.
       * @param font - Font to use when drawing text.
       * @see https://docs.scriptable.app/drawcontext/#-setfont
       */
    setFont(font: Font): void;
    /**
       * _Sets the text color used when drawing text._
       *
       * Sets the text color to be used when drawing text strings to the context.
       * @param color - Color to use when drawing text.
       * @see https://docs.scriptable.app/drawcontext/#-settextcolor
       */
    setTextColor(color: Color): void;
    /**
       * _Specifies that texts should be left aligned._
       *
       * Sets text alignment to left. Texts drawn after calling this will be left aligned inside the provided rectangle.
       * @see https://docs.scriptable.app/drawcontext/#-settextalignedleft
       */
    setTextAlignedLeft(): void;
    /**
       * _Specifies that texts should be center aligned._
       *
       * Sets text alignment to center. Texts drawn after calling this will be center aligned inside the provided rectangle.
       * @see https://docs.scriptable.app/drawcontext/#-settextalignedcenter
       */
    setTextAlignedCenter(): void;
    /**
       * _Specifies that texts should be right aligned._
       *
       * Sets text alignment to right. Texts drawn after calling this will be right aligned inside the provided rectangle.
       * @see https://docs.scriptable.app/drawcontext/#-settextalignedright
       */
    setTextAlignedRight(): void;
}
interface FileManagerState {
}
declare class AbsFileManager<S extends FileManagerState = FileManagerState> extends ScriptableClass<S> implements FileManager {
    static readonly identifier = "FileManager";
    /**
       * _Creates a local FileManager._
       *
       * Creates a file manager for operating with files stored locally.
       * @see https://docs.scriptable.app/filemanager/#local
       */
    static local(): FileManager;
    /**
       * _Creates an iCloud FileManager._
       *
       * Creates a file manager for operating with files stored in iCloud. iCloud must be enabled on the device in order to use this.
       * @see https://docs.scriptable.app/filemanager/#icloud
       */
    static iCloud(): FileManager;
    /**
       * _Read contents of a file as data._
       *
       * Reads the contents of the file specified by the file path as raw data. To read the file as a string see `readString(filePath)` and to read it as an image see `readImage(filePath)`.
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of the file to read.
       * @see https://docs.scriptable.app/filemanager/#-read
       */
    read(filePath: string): Data;
    /**
       * _Read contents of a file as string._
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of the file to read.
       * @see https://docs.scriptable.app/filemanager/#-readstring
       */
    readString(filePath: string): string;
    /**
       * _Read contents of a file as an image._
       *
       * Reads the contents of the file specified by the file path and converts it to an image.
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of the file to read.
       * @see https://docs.scriptable.app/filemanager/#-readimage
       */
    readImage(filePath: string): Image;
    /**
       * _Write data to a file._
       * @param filePath - Path of file to write to.
       * @param content - Data to write to disk.
       * @see https://docs.scriptable.app/filemanager/#-write
       */
    write(filePath: string, content: Data): void;
    /**
       * _Write a string to a file._
       *
       * Writes the content to the specified file path on disk. If the file does not already exist, it will be created. If the file already exists the contents of the file will be
       * overwritten with the new content.
       * @param filePath - Path of file to write to.
       * @param content - Content to write to disk.
       * @see https://docs.scriptable.app/filemanager/#-writestring
       */
    writeString(filePath: string, content: string): void;
    /**
       * _Write an image to a file._
       *
       * Writes the image to the specified file path on disk. If the file does not already exist, it will be created. If the file already exists the contents of the file will be overwritten
       * with the new content.
       * @param filePath - Path of file to write to.
       * @param image - Image to write to disk.
       * @see https://docs.scriptable.app/filemanager/#-writeimage
       */
    writeImage(filePath: string, image: Image): void;
    /**
       * _Removes a file._
       *
       * Removes the file at the specified path. Use with caution. Removed files cannot be restored.
       * @param filePath - Path of file to remove.
       * @see https://docs.scriptable.app/filemanager/#-remove
       */
    remove(filePath: string): void;
    /**
       * _Moves a file._
       *
       * Moves the file from the source path to the destination path. Caution: This operation will replace any existing file at the the destination.
       * @param sourceFilePath - Path of the file to move.
       * @param destinationFilePath - Path to move the file to.
       * @see https://docs.scriptable.app/filemanager/#-move
       */
    move(sourceFilePath: string, destinationFilePath: string): void;
    /**
       * _Copies a file._
       *
       * Copies the file from the source path to the destination path. If a file already exists at the destination file path, the operation will fail and the file will not be copied.
       * @param sourceFilePath - Path of the file to copy.
       * @param destinationFilePath - Path to copy the file to.
       * @see https://docs.scriptable.app/filemanager/#-copy
       */
    copy(sourceFilePath: string, destinationFilePath: string): void;
    /**
       * _Checks if the file exists._
       *
       * Checks if the file exists at the specified file path. Checking this before moving or copying to a destination can be a good idea as those operations will replace any existing file
       * at the destination file path.
       * @param filePath - File path to examine.
       * @see https://docs.scriptable.app/filemanager/#-fileexists
       */
    fileExists(filePath: string): boolean;
    /**
       * _Checks if a path points to a directory._
       * @param path - Path to examine.
       * @see https://docs.scriptable.app/filemanager/#-isdirectory
       */
    isDirectory(path: string): boolean;
    /**
       * _Creates a directory at the specified path._
       *
       * You can optionally create all intermediate directories.
       * @param path - Path of directory to create.
       * @param intermediateDirectories - Whether to create all intermediate directories. Defaults to false.
       * @see https://docs.scriptable.app/filemanager/#-createdirectory
       */
    createDirectory(path: string, intermediateDirectories?: boolean): void;
    /**
       * _Path of temporary directory._
       *
       * Used to retrieve the path of a temporary directory on disk. Data persisted in a temporary directory will generally live shorter than data persisted in the cache directory.
       *
       * The operating system may at any time delete files stored in this directory and therefore you should not rely on it for long time storage. If you need long time storage, see
       * documentsDirectory() or libraryDirectory(). This directory is not shared between the app, the action extension and Siri.
       * @see https://docs.scriptable.app/filemanager/#-temporarydirectory
       */
    temporaryDirectory(): string;
    /**
       * _Path of cache directory._
       *
       * Used to retrieve the path of a cache directory on disk. The operating system may at any time delete files stored in this directory and therefore you should not rely on it for long
       * time storage.
       *
       * Data persisted in the cache directory will generally live longer than data persisted in a temporary directory.
       *
       * If you need long time storage, see documentsDirectory() or libraryDirectory(). This directory is not shared between the app, the action extension and Siri.
       * @see https://docs.scriptable.app/filemanager/#-cachedirectory
       */
    cacheDirectory(): string;
    /**
       * _Path of documents directory._
       *
       * Used to retrieve the path to the documents directory. Your scripts are stored in this directory. If you have iCloud enabled, your scripts will be stored in the documents directory
       * in iCloud otherwise they will be stored in the local documents directory. The directory can be used for long time storage. Documents stored in this directory can be accessed using
       * the Files app. Files stored in the local documents directory will not appear in the Files app.
       * @see https://docs.scriptable.app/filemanager/#-documentsdirectory
       */
    documentsDirectory(): string;
    /**
       * _Path of library directory._
       *
       * Used to retrieve the path to the library directory. The directory can be used for long time storage. Documents stored in this directory cannot be accessed using the Files app.
       * @see https://docs.scriptable.app/filemanager/#-librarydirectory
       */
    libraryDirectory(): string;
    /**
       * _Joins two path components._
       *
       * Joins two paths to created one path. For example to join the path to a directory with the name of a file. This is the suggested approach for creating new file paths passed to the
       * read and write functions of a FileManager.
       * @param lhsPath - Left-hand side part of the new path.
       * @param rhsPath - Right-hand side part of the new path.
       * @see https://docs.scriptable.app/filemanager/#-joinpath
       */
    joinPath(lhsPath: string, rhsPath: string): string;
    /**
       * _Reads all tags from a file._
       *
       * The tags are read from the file at the specified path. Tags can either be read, added and removed using the Files app by using the APIs provided by a FileManager.
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of file to read tags from.
       * @see https://docs.scriptable.app/filemanager/#-alltags
       */
    allTags(filePath: string): string[];
    /**
       * _Adds a tag to a file._
       *
       * A tag can only be added to a file once. It is not possible to specify a color for the tag. You can create the tags using the Files app to specify the color and then add them to
       * files afterwards using the FileManager API.
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of file to add the tag to.
       * @param tag - Tag to add. This can be an existing tag or a new tag.
       * @see https://docs.scriptable.app/filemanager/#-addtag
       */
    addTag(filePath: string, tag: string): void;
    /**
       * _Removes a tag from a file._
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of file to remove the tag from.
       * @param tag - Tag to remove.
       * @see https://docs.scriptable.app/filemanager/#-removetag
       */
    removeTag(filePath: string, tag: string): void;
    /**
       * _Reads an extended attribute from a file._
       *
       * Extended attributes are metadata that can be stored on a file. Note that extended attributes are not synced with iCloud.
       *
       * The function will return `null` if the attribute does not exist.
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of file to read extended attribute from.
       * @param name - Name of the extended attribute to read.
       * @see https://docs.scriptable.app/filemanager/#-readextendedattribute
       */
    readExtendedAttribute(filePath: string, name: string): string;
    /**
       * _Writes an extended attribute to a file._
       *
       * Extended attributes are metadata that can be stored on a file. Note that extended attributes are not synced with iCloud.
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of file to add an extended attribute to.
       * @param value - Value of the extended attribute.
       * @param name - Name of the extended attribute. This is used to retrieve the value at a later point.
       * @see https://docs.scriptable.app/filemanager/#-writeextendedattribute
       */
    writeExtendedAttribute(filePath: string, value: string, name: string): void;
    /**
       * _Removes an extended attribute from a file._
       *
       * Extended attributes are metadata that can be stored on a file. Note that extended attributes are not synced with iCloud.
       *
       * The function will error if the file does not exist or if it exists in iCloud but has not been download. Use `fileExists(filePath)` to check if a file exists and
       * `downloadFileFromiCloud(filePath)` to download the file. Note that it is always safe to call `downloadFileFromiCloud(filePath)`, even if the file is stored locally on the device.
       * @param filePath - Path of file to add an extended attribute to.
       * @param name - Name of the extended attribute to remove.
       * @see https://docs.scriptable.app/filemanager/#-removeextendedattribute
       */
    removeExtendedAttribute(filePath: string, name: string): void;
    /**
       * _Reads all extended attributes on a file._
       *
       * Extended attributes are metadata that can be stored on a file. Note that extended attributes are not synced with iCloud.
       * @param filePath - Path of file to read extended attributes from.
       * @see https://docs.scriptable.app/filemanager/#-allextendedattributes
       */
    allExtendedAttributes(filePath: string): string[];
    /**
       * _Gets the UTI of the specified file._
       *
       * The Uniform Type Identifier is a string that identifies the type of file.
       * @param filePath - Path of file to get UTI of.
       * @see https://docs.scriptable.app/filemanager/#-getuti
       */
    getUTI(filePath: string): string;
    /**
       * _Lists content of directory._
       *
       * Lists all the contents in the specified directory. The returned array contains filenames of all files and directories in the specified directory.
       * @param directoryPath - Path to directory.
       * @see https://docs.scriptable.app/filemanager/#-listcontents
       */
    listContents(directoryPath: string): string[];
    /**
       * _Get name of a file._
       *
       * Takes a file path and returns the name of the file. Also supports getting the name of a directory. The returned file name optionally includes the extension of the file.
       * @param filePath - path of file to get name of.
       * @param includeFileExtension - Whether or not the file extension should be included. Defaults to false.
       * @see https://docs.scriptable.app/filemanager/#-filename
       */
    fileName(filePath: string, includeFileExtension?: boolean): string;
    /**
       * _Get extension of a file._
       *
       * Takes a file path and returns the extension of the file, e.g. ".jpg" or ".js". Returns en empty string for directories.
       * @param filePath - Path of file to get extension from.
       * @see https://docs.scriptable.app/filemanager/#-fileextension
       */
    fileExtension(filePath: string): string;
    /**
       * _Get path to a bookmarked file or folder._
       *
       * Gets the path to a bookmarked file or filder. Use file bookmarks to access files and folders outside Scriptables documents directory.
       *
       * You can edit your file bookmarks from Scriptables settings.
       *
       * The function will throw an error if the bookmark doesn't exist.
       *
       * Please beware that bookmarks created from Scriptables settings only can be used when running a script in the app and not from the Share Sheet, Siri and Shortcuts. If you wish to
       * use a bookmark from Siri or the Shortcuts app, the bookmark must be created using Scriptables "Create File Bookmark" shortcut action using the Shortcuts app.
       * @param name - Name of bookmark to create path for.
       * @see https://docs.scriptable.app/filemanager/#-bookmarkedpath
       */
    bookmarkedPath(name: string): string;
    /**
       * _Check if a bookmark exists._
       *
       * Checks if a file bookmark exists with the specified name.
       *
       * You can edit your file bookmarks from Scriptables settings.
       *
       * Please beware that bookmarks created from Scriptables settings only can be used when running a script in the app and not from the Share Sheet, Siri and Shortcuts. If you wish to
       * use a bookmark from Siri or the Shortcuts app, the bookmark must be created using Scriptables "Create File Bookmark" shortcut action using the Shortcuts app.
       * @param name - Name of bookmark.
       * @see https://docs.scriptable.app/filemanager/#-bookmarkexists
       */
    bookmarkExists(name: string): boolean;
    /**
       * _Download file from iCloud if necessary._
       *
       * Downloads the file from iCloud if it has not already been downloaded. If you pass in a path to a file that is not stored in iCloud, the returned promise will be resolved
       * immediately making it safe to pass in any file path.
       * @param filePath - Path of file to download from iCloud.
       * @see https://docs.scriptable.app/filemanager/#-downloadfilefromicloud
       */
    downloadFileFromiCloud(filePath: string): Promise<void>;
    /**
       * _Checks if a file is stored in iCloud._
       *
       * Checks if a file is stored in iCloud or locally on the device. The function returns false if the file does not exist. Check if a file exists using `fileExists(filePath)`
       * @param filePath - Path of file.
       * @see https://docs.scriptable.app/filemanager/#-isfilestoredinicloud
       */
    isFileStoredIniCloud(filePath: string): boolean;
    /**
       * _Checks if a file has been downloaded._
       *
       * If a file is stored in iCloud and it has not been downloaded, this function returns false. In that case, the file can be downloaded using `downloadFileFromiCloud(filePath`. If the
       * file is not stored in iCloud but rather locally on the device, this function returns true.
       *
       * The function returns false if the file does not exist. Check if a file exists using `fileExists(filePath)`
       * @param filePath - Path of file.
       * @see https://docs.scriptable.app/filemanager/#-isfiledownloaded
       */
    isFileDownloaded(filePath: string): boolean;
    /**
       * _Reads the creation date of a file._
       *
       * The returned value will be null if the creation date cannot be read.
       * @param filePath - Path of file.
       * @see https://docs.scriptable.app/filemanager/#-creationdate
       */
    creationDate(filePath: string): Date;
    /**
       * _Reads the modification date of a file._
       *
       * The returned value will be null if the modification date cannot be read.
       * @param filePath - Path of file.
       * @see https://docs.scriptable.app/filemanager/#-modificationdate
       */
    modificationDate(filePath: string): Date;
    /**
       * _Size of the file in kilobytes._
       *
       * The returned value will be null if the file size cannot be read.
       * @param filePath - Path of file.
       * @see https://docs.scriptable.app/filemanager/#-filesize
       */
    fileSize(filePath: string): number;
    /**
       * _Reads all file bookmarks created in settings._
       *
       * File bookmarks are used to bookmark a file or a folder to read from it or write to it later. File bookmarks are created from Scriptables settings.
       *
       * This function returns all file bookmarks as an array of objects that take the following form.
       *
       *     {
       *       "name": "My Bookmark",
       *       "source": "host"
       *     }
       *
       * The source can either be `host` for file bookmarks that can be used in the app or `siri_shortcuts` for file bookmarks that can be used in Siri and Shortcuts.
       * @see https://docs.scriptable.app/filemanager/#-allfilebookmarks
       */
    allFileBookmarks(): FileManager.AllFileBookmarks[];
}
interface FontState {
}
declare class AbsFont<S extends FontState = FontState> extends ScriptableClass<S> implements Omit<Font, 'font'> {
    static readonly identifier = "Font";
    /**
       * _Preferred font for large titles._
       * @see https://docs.scriptable.app/font/#largetitle
       */
    static largeTitle(): Font;
    /**
       * _Preferred font for first level hierarchical headings._
       * @see https://docs.scriptable.app/font/#title1
       */
    static title1(): Font;
    /**
       * _Preferred font for second level hierarchical headings._
       * @see https://docs.scriptable.app/font/#title2
       */
    static title2(): Font;
    /**
       * _Preferred font for third level hierarchical headings._
       * @see https://docs.scriptable.app/font/#title3
       */
    static title3(): Font;
    /**
       * _Preferred font for headings._
       * @see https://docs.scriptable.app/font/#headline
       */
    static headline(): Font;
    /**
       * _Preferred font for subheadings._
       * @see https://docs.scriptable.app/font/#subheadline
       */
    static subheadline(): Font;
    /**
       * _Preferred font for body texts._
       * @see https://docs.scriptable.app/font/#body
       */
    static body(): Font;
    /**
       * _Preferred font for callouts._
       * @see https://docs.scriptable.app/font/#callout
       */
    static callout(): Font;
    /**
       * _Preferred font for footnotes._
       * @see https://docs.scriptable.app/font/#footnote
       */
    static footnote(): Font;
    /**
       * _Preferred font for standard captions._
       * @see https://docs.scriptable.app/font/#caption1
       */
    static caption1(): Font;
    /**
       * _Preferred font for alternate captions._
       * @see https://docs.scriptable.app/font/#caption2
       */
    static caption2(): Font;
    /**
       * _Creates a system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#systemfont
       */
    static systemFont(size: number): Font;
    /**
       * _Creates an ultra light system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#ultralightsystemfont
       */
    static ultraLightSystemFont(size: number): Font;
    /**
       * _Creates a thin system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#thinsystemfont
       */
    static thinSystemFont(size: number): Font;
    /**
       * _Creates a light system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#lightsystemfont
       */
    static lightSystemFont(size: number): Font;
    /**
       * _Creates a regular system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#regularsystemfont
       */
    static regularSystemFont(size: number): Font;
    /**
       * _Creates a medium system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#mediumsystemfont
       */
    static mediumSystemFont(size: number): Font;
    /**
       * _Creates a semibold system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#semiboldsystemfont
       */
    static semiboldSystemFont(size: number): Font;
    /**
       * _Creates a bold system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#boldsystemfont
       */
    static boldSystemFont(size: number): Font;
    /**
       * _Creates a heavy system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#heavysystemfont
       */
    static heavySystemFont(size: number): Font;
    /**
       * _Creates a font with the system appearance with the black weight._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#blacksystemfont
       */
    static blackSystemFont(size: number): Font;
    /**
       * _Creates an italic system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#italicsystemfont
       */
    static italicSystemFont(size: number): Font;
    /**
       * _Creates an ultra light monospaced system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#ultralightmonospacedsystemfont
       */
    static ultraLightMonospacedSystemFont(size: number): Font;
    /**
       * _Creates a thin monospaced system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#thinmonospacedsystemfont
       */
    static thinMonospacedSystemFont(size: number): Font;
    /**
       * _Creates a light monospaced system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#lightmonospacedsystemfont
       */
    static lightMonospacedSystemFont(size: number): Font;
    /**
       * _Creates a regular monospaced system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#regularmonospacedsystemfont
       */
    static regularMonospacedSystemFont(size: number): Font;
    /**
       * _Creates a medium monospaced system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#mediummonospacedsystemfont
       */
    static mediumMonospacedSystemFont(size: number): Font;
    /**
       * _Creates a semibold monospaced system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#semiboldmonospacedsystemfont
       */
    static semiboldMonospacedSystemFont(size: number): Font;
    /**
       * _Creates a bold monospaced system font.._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#boldmonospacedsystemfont
       */
    static boldMonospacedSystemFont(size: number): Font;
    /**
       * _Creates a heavy monospaced system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#heavymonospacedsystemfont
       */
    static heavyMonospacedSystemFont(size: number): Font;
    /**
       * _Creates a monospaced system font with the black weight._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#blackmonospacedsystemfont
       */
    static blackMonospacedSystemFont(size: number): Font;
    /**
       * _Creates an ultra light and rounded system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#ultralightroundedsystemfont
       */
    static ultraLightRoundedSystemFont(size: number): Font;
    /**
       * _Creates a thin and rounded system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#thinroundedsystemfont
       */
    static thinRoundedSystemFont(size: number): Font;
    /**
       * _Creates a light and rounded system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#lightroundedsystemfont
       */
    static lightRoundedSystemFont(size: number): Font;
    /**
       * _Creates a regular and rounded system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#regularroundedsystemfont
       */
    static regularRoundedSystemFont(size: number): Font;
    /**
       * _Creates a medium and rounded system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#mediumroundedsystemfont
       */
    static mediumRoundedSystemFont(size: number): Font;
    /**
       * _Creates a semibold and rounded system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#semiboldroundedsystemfont
       */
    static semiboldRoundedSystemFont(size: number): Font;
    /**
       * _Creates a bold and rounded system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#boldroundedsystemfont
       */
    static boldRoundedSystemFont(size: number): Font;
    /**
       * _Creates a heavy and rounded system font._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#heavyroundedsystemfont
       */
    static heavyRoundedSystemFont(size: number): Font;
    /**
       * _Creates a rounded system font with the black weight._
       * @param size - Size of the text.
       * @see https://docs.scriptable.app/font/#blackroundedsystemfont
       */
    static blackRoundedSystemFont(size: number): Font;
}
interface ImageState {
    size: Size;
}
declare class AbsImage<S extends ImageState = ImageState> extends ScriptableClass<S> implements Image {
    static readonly identifier = "Image";
    /**
       * _Creates an image from file._
       *
       * Loads an image from the specified file path. If the image could not be read, the function will return null.
       * @param filePath - File path to read image from.
       * @see https://docs.scriptable.app/image/#fromfile
       */
    static fromFile(filePath: string): Image;
    /**
       * _Creates an image from raw data._
       *
       * Loads an image from the raw data. If the image could not be read, the function will return null.
       * @param data - Data to read image from.
       * @see https://docs.scriptable.app/image/#fromdata
       */
    static fromData(data: Data): Image;
    get size(): Size;
    set size(value: Size);
}
interface LinearGradientState {
    colors: Color[];
    locations: number[];
    startPoint: Point;
    endPoint: Point;
}
declare class AbsLinearGradient<S extends LinearGradientState = LinearGradientState> extends ScriptableClass<S> implements LinearGradient {
    static readonly identifier = "LinearGradient";
    get colors(): Color[];
    set colors(value: Color[]);
    get locations(): number[];
    set locations(value: number[]);
    get startPoint(): Point;
    set startPoint(value: Point);
    get endPoint(): Point;
    set endPoint(value: Point);
}
interface ListWidgetState {
    backgroundColor: Color;
    backgroundImage: Image;
    backgroundGradient: LinearGradient;
    addAccessoryWidgetBackground: boolean;
    spacing: number;
    url: string;
    refreshAfterDate: Date;
}
declare class AbsListWidget<S extends ListWidgetState = ListWidgetState> extends ScriptableClass<S> implements ListWidget {
    static readonly identifier = "ListWidget";
    get backgroundColor(): Color;
    set backgroundColor(value: Color);
    get backgroundImage(): Image;
    set backgroundImage(value: Image);
    get backgroundGradient(): LinearGradient;
    set backgroundGradient(value: LinearGradient);
    get addAccessoryWidgetBackground(): boolean;
    set addAccessoryWidgetBackground(value: boolean);
    get spacing(): number;
    set spacing(value: number);
    get url(): string;
    set url(value: string);
    get refreshAfterDate(): Date;
    set refreshAfterDate(value: Date);
    /**
       * _Add text to the widget._
       *
       * Adds a text element to the widget. Use the properties on the returned element to style the text.
       * @see https://docs.scriptable.app/listwidget/#-addtext
       */
    addText(text: string): WidgetText;
    /**
       * _Add date to the widget._
       *
       * Adds a date element to the widget. Use the properties on the returned element to style the date.
       * @see https://docs.scriptable.app/listwidget/#-adddate
       */
    addDate(date: Date): WidgetDate;
    /**
       * _Add image to the widget._
       *
       * Adds an image element to the widget. Use the properties on the returned element to style the image.
       * @see https://docs.scriptable.app/listwidget/#-addimage
       */
    addImage(image: Image): WidgetImage;
    /**
       * _Add spacer._
       *
       * Adds a spacer to the widget. This can be used to offset the content vertically in the widget.
       * @param length - Length of the spacer. Pass null to create a spacer with a flexible length.
       * @see https://docs.scriptable.app/listwidget/#-addspacer
       */
    addSpacer(length?: number): WidgetSpacer;
    /**
       * _Add stack._
       *
       * Adds a stack to the widget. Stacks layout elements horizontally by default.
       * @see https://docs.scriptable.app/listwidget/#-addstack
       */
    addStack(): WidgetStack;
    /**
       * _Set padding._
       *
       * Sets the padding on each side of the widget.
       * @param top - Padding on the top edge.
       * @param leading - Padding on the leading edge.
       * @param bottom - Padding on the bottom edge.
       * @param trailing - Padding on the trailing edge.
       * @see https://docs.scriptable.app/listwidget/#-setpadding
       */
    setPadding(top: number, leading: number, bottom: number, trailing: number): void;
    /**
       * _Use the default padding._
       *
       * Configure the widget to use the default padding. Any padding previously defined with `setPadding()` will be discarded.
       * @see https://docs.scriptable.app/listwidget/#-usedefaultpadding
       */
    useDefaultPadding(): void;
    /**
       * _Presents a preview of the widget._
       *
       * The widget is presented in its small size.
       *
       * Widgets on the Home Screen are updated periodically so while working on your widget you may want to preview it in the app.
       * @see https://docs.scriptable.app/listwidget/#-presentsmall
       */
    presentSmall(): Promise<void>;
    /**
       * _Presents a preview of the widget._
       *
       * The widget is presented in its medium size.
       *
       * Widgets on the Home Screen are updated periodically so while working on your widget you may want to preview it in the app.
       * @see https://docs.scriptable.app/listwidget/#-presentmedium
       */
    presentMedium(): Promise<void>;
    /**
       * _Presents a preview of the widget._
       *
       * The widget is presented in its large size.
       *
       * Widgets on the Home Screen are updated periodically so while working on your widget you may want to preview it in the app.
       * @see https://docs.scriptable.app/listwidget/#-presentlarge
       */
    presentLarge(): Promise<void>;
    /**
       * _Presents a preview of the widget._
       *
       * The widget is presented in its extra large size.
       *
       * Widgets on the Home Screen are updated periodically so while working on your widget you may want to preview it in the app.
       *
       * The extra large widget is only available on iPads running iOS 15 and newer.
       * @see https://docs.scriptable.app/listwidget/#-presentextralarge
       */
    presentExtraLarge(): Promise<void>;
    /**
       * _Presents a preview of the widget._
       *
       * The widget is presented in its accessory inline size that is suitable to be displayed above the clock on the Lock Screen.
       *
       * The preview is an estimated representation of the widget and is not accurate. Widgets placed on the Lock Screen change appearance based on the wallpaper and tint color of the Lock
       * Screen, and as such, they cannot be previewed accurately in Scriptable.
       *
       * Widgets on the Lock Screen are updated periodically so while working on your widget you may want to preview it in the app.
       *
       * The accessory inline widget is available on iPhones running iOS 16 and newer and can display a single image and a single text. Any additional elements will be filtered away during
       * presentation.
       * @see https://docs.scriptable.app/listwidget/#-presentaccessoryinline
       */
    presentAccessoryInline(): Promise<void>;
    /**
       * _Presents a preview of the widget._
       *
       * The widget is presented in its circular accessory size that is suitable to be displayed below the clock on the Lock Screen.
       *
       * The preview is an estimated representation of the widget and is not accurate. Widgets placed on the Lock Screen change appearance based on the wallpaper and tint color of the Lock
       * Screen, and as such, they cannot be previewed accurately in Scriptable.
       *
       * Widgets on the Lock Screen are updated periodically so while working on your widget you may want to preview it in the app.
       *
       * The circular accessory widget is available on iPhones running iOS 16 and newer.
       * @see https://docs.scriptable.app/listwidget/#-presentaccessorycircular
       */
    presentAccessoryCircular(): Promise<void>;
    /**
       * _Presents a preview of the widget._
       *
       * The widget is presented in its rectangular accessory size that is suitable to be displayed below the clock on the Lock Screen.
       *
       * The preview is an estimated representation of the widget and is not accurate. Widgets placed on the Lock Screen change appearance based on the wallpaper and tint color of the Lock
       * Screen, and as such, they cannot be previewed accurately in Scriptable.
       *
       * Widgets on the Lock Screen are updated periodically so while working on your widget you may want to preview it in the app.
       *
       * The rectangular accessory widget is available on iPhones running iOS 16 and newer.
       * @see https://docs.scriptable.app/listwidget/#-presentaccessoryrectangular
       */
    presentAccessoryRectangular(): Promise<void>;
}
interface MailState {
    toRecipients: string[];
    ccRecipients: string[];
    bccRecipients: string[];
    subject: string;
    body: string;
    isBodyHTML: boolean;
    preferredSendingEmailAddress: string;
}
declare class AbsMail<S extends MailState = MailState> extends ScriptableClass<S> implements Mail {
    static readonly identifier = "Mail";
    get toRecipients(): string[];
    set toRecipients(value: string[]);
    get ccRecipients(): string[];
    set ccRecipients(value: string[]);
    get bccRecipients(): string[];
    set bccRecipients(value: string[]);
    get subject(): string;
    set subject(value: string);
    get body(): string;
    set body(value: string);
    get isBodyHTML(): boolean;
    set isBodyHTML(value: boolean);
    get preferredSendingEmailAddress(): string;
    set preferredSendingEmailAddress(value: string);
    /**
       * _Send the mail._
       *
       * Presents a screen from which the mail can be sent. The mail will not be sent until you have confirmed it from the presented screen.
       * @see https://docs.scriptable.app/mail/#-send
       */
    send(): Promise<void>;
    /**
       * _Adds an image attachment to the mail._
       * @param image - Image to add to the mail.
       * @see https://docs.scriptable.app/mail/#-addimageattachment
       */
    addImageAttachment(image: Image): void;
    /**
       * _Adds a file attachment to the mail._
       * @param filePath - Path of file to add to the mail.
       * @see https://docs.scriptable.app/mail/#-addfileattachment
       */
    addFileAttachment(filePath: string): void;
    /**
       * _Adds a data attachment to the mail._
       *
       * When adding a data attachment to the mail, you are responsible for providing a valid MIME type and filename. It is advised to use `addImageAttachment` and `addFileAttachment`
       * whenever possible.
       * @param data - Data representation of file to add to the mail.
       * @param mimeType - MIME type of file represented by the data.
       * @param filename - Name of the file represented by the data.
       * @see https://docs.scriptable.app/mail/#-adddataattachment
       */
    addDataAttachment(data: Data, mimeType: string, filename: string): void;
}
interface MessageState {
    recipients: string[];
    body: string;
}
declare class AbsMessage<S extends MessageState = MessageState> extends ScriptableClass<S> implements Message {
    static readonly identifier = "Message";
    get recipients(): string[];
    set recipients(value: string[]);
    get body(): string;
    set body(value: string);
    /**
       * _Send the message._
       *
       * Presents a screen from which the message can be sent. The message will not be sent until you have confirmed it from the presented screen.
       * @see https://docs.scriptable.app/message/#-send
       */
    send(): Promise<void>;
    /**
       * _Adds an image attachment to the message._
       * @param image - Image to add to the message.
       * @see https://docs.scriptable.app/message/#-addimageattachment
       */
    addImageAttachment(image: Image): void;
    /**
       * _Adds a file attachment to the message._
       * @param filePath - Path of file to add to the message.
       * @see https://docs.scriptable.app/message/#-addfileattachment
       */
    addFileAttachment(filePath: string): void;
    /**
       * _Adds a data attachment to the message._
       *
       * When adding a data attachment to the message, you are responsible for providing a valid Uniform Type Identifier and filename. It is advised to use `addImageAttachment` and
       * `addFileAttachment` whenever possible.
       * @param data - Data representation of file to add to the message.
       * @param uti - UTI of file represented by the data.
       * @param filename - Name of the file represented by the data.
       * @see https://docs.scriptable.app/message/#-adddataattachment
       */
    addDataAttachment(data: Data, uti: string, filename: string): void;
}
interface NotificationState {
    identifier: string;
    title: string;
    subtitle: string;
    body: string;
    preferredContentHeight: number;
    badge: number;
    threadIdentifier: string;
    userInfo: {
        [key: string]: any;
    };
    sound: "default" | "accept" | "alert" | "complete" | "event" | "failure" | "piano_error" | "piano_success" | "popup";
    openURL: string;
    deliveryDate: Date;
    nextTriggerDate: Date;
    scriptName: string;
    actions: Notification.Actions;
}
declare class AbsNotification<S extends NotificationState = NotificationState> extends ScriptableClass<S> implements Notification {
    static readonly identifier = "Notification";
    /**
       * _All pending notifications._
       *
       * Fetches all notifications that have been scheduled from Scriptable and are waiting to be delivered.
       * @see https://docs.scriptable.app/notification/#allpending
       */
    static allPending(): Promise<Notification[]>;
    /**
       * _Delivered notifications displayed in the Notification Center._
       *
       * Fetches all notifications that have been scheduled from Scriptable and that are still displayed in the Notification Center of iOS.
       * @see https://docs.scriptable.app/notification/#alldelivered
       */
    static allDelivered(): Promise<Notification[]>;
    /**
       * _Removes all pending notifications._
       *
       * Removes all notifications that have been scheduled from Scriptable and are waiting to be delivered.
       *
       * Use with caution. This removes all notifications scheduled across all of your scripts and the action cannot be undone.
       * @see https://docs.scriptable.app/notification/#removeallpending
       */
    static removeAllPending(): Promise<void>;
    /**
       * _Removes all delivered notifications._
       *
       * Removes all notifications that have been scheduled from Scriptable and that are still displayed in the Notification Center of iOS.
       * @see https://docs.scriptable.app/notification/#removealldelivered
       */
    static removeAllDelivered(): Promise<void>;
    /**
       * _Removes pending notifications._
       *
       * Removes notifications with the specified identifiers. The notifications are only removed if they are pending, that is they have been scheduled and are waiting to be delivered. To
       * remove delivered notifications, see `Notification.removeDelivered()`.
       * @see https://docs.scriptable.app/notification/#removepending
       */
    static removePending(identifiers: readonly string[]): Promise<void>;
    /**
       * _Removes delivered notifications._
       *
       * Removes notifications with the specified identifiers. The notifications are only removed if they have been delivered. To remove pending notifications, see
       * `Notification.removePending()`.
       * @see https://docs.scriptable.app/notification/#removedelivered
       */
    static removeDelivered(identifiers: readonly string[]): Promise<void>;
    /**
       * _Resets the current notification._
       *
       * Effectively sets `args.notification` to null.
       *
       * When a notification scheduled from Scriptable has been tapped to open the app or while the app was open, `args.notification` will have a value until Scriptable is quit. You can
       * manually reset the value using `Notification.resetCurrent`.
       * @see https://docs.scriptable.app/notification/#resetcurrent
       */
    static resetCurrent(): void;
    get identifier(): string;
    set identifier(value: string);
    get title(): string;
    set title(value: string);
    get subtitle(): string;
    set subtitle(value: string);
    get body(): string;
    set body(value: string);
    get preferredContentHeight(): number;
    set preferredContentHeight(value: number);
    get badge(): number;
    set badge(value: number);
    get threadIdentifier(): string;
    set threadIdentifier(value: string);
    get userInfo(): {
        [key: string]: any;
    };
    set userInfo(value: {
        [key: string]: any;
    });
    get sound(): "default" | "accept" | "alert" | "complete" | "event" | "failure" | "piano_error" | "piano_success" | "popup";
    set sound(value: "default" | "accept" | "alert" | "complete" | "event" | "failure" | "piano_error" | "piano_success" | "popup");
    get openURL(): string;
    set openURL(value: string);
    get deliveryDate(): Date;
    set deliveryDate(value: Date);
    get nextTriggerDate(): Date;
    set nextTriggerDate(value: Date);
    get scriptName(): string;
    set scriptName(value: string);
    get actions(): Notification.Actions;
    set actions(value: Notification.Actions);
    /**
       * _Schedules the notification._
       *
       * When a new notification is constructed, it must be scheduled, otherwise it will not be delivered. If an existing notification is modified, it must also be scheduled again for the
       * changes to take effect.
       * @see https://docs.scriptable.app/notification/#-schedule
       */
    schedule(): Promise<void>;
    /**
       * _Removes the notification._
       *
       * Removes all future triggers of the notification.
       * @see https://docs.scriptable.app/notification/#-remove
       */
    remove(): Promise<void>;
    /**
       * _Sets the notification to be triggered on a date and time._
       * @param date - Date and time to trigger the notification on.
       * @see https://docs.scriptable.app/notification/#-settriggerdate
       */
    setTriggerDate(date: Date): void;
    /**
       * _Sets the notification to be triggered daily._
       *
       * Sets the notification to be triggered on a specific time of the day. When the notification repeats, it will be sent at the same time on all future days. If the notification is not
       * repating it will be sent on the next occurrence of the specified time.
       * @param hour - Hour of the day to trigger the notification.
       * @param minute - Minute of the day to trigger the notification.
       * @param repeats - If true the notification will be sent daily on the specified time, otherwise it will only be sent once. Defaults to false.
       * @see https://docs.scriptable.app/notification/#-setdailytrigger
       */
    setDailyTrigger(hour: number, minute: number, repeats?: boolean): void;
    /**
       * _Sets the notification to be triggered weekly._
       *
       * Sets the notification to be triggered on a specific day of the week and a specific time of that day. When the notification repeats, it will be sent at the same time on all future
       * days. If the notification is not repating it will be sent on the next occurrence of the specified time.
       * @param weekday - Day of the week to trigger the notification.
       * @param hour - Hour of the day to trigger the notification.
       * @param minute - Minute of the day to trigger the notification.
       * @param repeats - If true the notification will be sent daily on the specified time, otherwise it will only be sent once. Defaults to false.
       * @see https://docs.scriptable.app/notification/#-setweeklytrigger
       */
    setWeeklyTrigger(weekday: number, hour: number, minute: number, repeats?: boolean): void;
    /**
       * _Adds an action button._
       *
       * Actions are shown as buttons in the notification. When screen space is unlimited, the system shows up to 10 actions. When the space is limited the system shows at most two actions.
       * @param title - Title of the action.
       * @param url - URL to open when choosing the action.
       * @param destructive - Optional. If set to true, the button is displayed with special highlighting to indicate that it performs a destructive task. Defaults to false.
       * @see https://docs.scriptable.app/notification/#-addaction
       */
    addAction(title: string, url: string, destructive?: boolean): void;
}
interface PathState {
}
declare class AbsPath<S extends PathState = PathState> extends ScriptableClass<S> implements Path {
    static readonly identifier = "Path";
    /**
       * _Moves to a point._
       *
       * Moves to a point without drawing a line between the current point and the new point.
       * @param point - Point to move to.
       * @see https://docs.scriptable.app/path/#-move
       */
    move(point: Point): void;
    /**
       * _Adds a line to a point._
       *
       * Add a line from the current point, e.g. set using the move method, and to the new point.
       * @param point - Point to add line to.
       * @see https://docs.scriptable.app/path/#-addline
       */
    addLine(point: Point): void;
    /**
       * _Adds a rectangle._
       *
       * This is a convenience function for adding a rectangle to the path starting from the lower left corner and drawing the lines counter-clockwise until the rectangle is closed.
       * @param rect - Rectangle to add.
       * @see https://docs.scriptable.app/path/#-addrect
       */
    addRect(rect: Rect): void;
    /**
       * _Adds an ellipse._
       *
       * Adds an ellipse incapsulated by the provided rectangle to the path.
       * @param rect - Rectangle incapsulating the ellipse.
       * @see https://docs.scriptable.app/path/#-addellipse
       */
    addEllipse(rect: Rect): void;
    /**
       * _Adds a rounded rectangle._
       *
       * Adds a rounded rectangle to the path. The corner width specifies the horizontal size of the corner and the corner height specifies the the vertical size of the corner.
       * @param rect - Rectangle to add.
       * @param cornerWidth - Horizontal size of the rounded corner.
       * @param cornerHeight - Vertical size of the rounded corner.
       * @see https://docs.scriptable.app/path/#-addroundedrect
       */
    addRoundedRect(rect: Rect, cornerWidth: number, cornerHeight: number): void;
    /**
       * _Adds a cubic curve to a point._
       *
       * Adds a cubic Bézier curve to the path with the specified end point and control points.
       * @param point - End point of the curve.
       * @param control1 - First control point of the curve.
       * @param control2 - Second control point of the curve.
       * @see https://docs.scriptable.app/path/#-addcurve
       */
    addCurve(point: Point, control1: Point, control2: Point): void;
    /**
       * _Adds a quadratic curve to a point._
       *
       * Adds a quadratic Bézier curve to the specified end point with the specified control point.
       * @param point - End point of the curve.
       * @param control - Control point of the curve.
       * @see https://docs.scriptable.app/path/#-addquadcurve
       */
    addQuadCurve(point: Point, control: Point): void;
    /**
       * _Adds a set of lines._
       *
       * Adds straight lines between an array of points. Calling this method is equivalent to calling the move function with the first point in the array of points and then calling addLine
       * on the subsequent points in the array.
       * @param points - Points to add lines between.
       * @see https://docs.scriptable.app/path/#-addlines
       */
    addLines(points: readonly Point[]): void;
    /**
       * _Adds a set of rectangles._
       *
       * Calling this is equivalent to repeatedly calling addRect.
       * @param rects - Rectangles to add.
       * @see https://docs.scriptable.app/path/#-addrects
       */
    addRects(rects: readonly Rect[]): void;
    /**
       * _Closes a sub path._
       *
       * Adds a straight line from the current point to the start of the current subpath.
       * @see https://docs.scriptable.app/path/#-closesubpath
       */
    closeSubpath(): void;
}
interface PointState {
    x: number;
    y: number;
}
declare class AbsPoint<S extends PointState = PointState> extends ScriptableClass<S> implements Point {
    static readonly identifier = "Point";
    get x(): number;
    set x(value: number);
    get y(): number;
    set y(value: number);
}
interface RectState {
    minX: number;
    minY: number;
    maxX: number;
    maxY: number;
    x: number;
    y: number;
    width: number;
    height: number;
    origin: Point;
    size: Size;
}
declare class AbsRect<S extends RectState = RectState> extends ScriptableClass<S> implements Rect {
    static readonly identifier = "Rect";
    get minX(): number;
    set minX(value: number);
    get minY(): number;
    set minY(value: number);
    get maxX(): number;
    set maxX(value: number);
    get maxY(): number;
    set maxY(value: number);
    get x(): number;
    set x(value: number);
    get y(): number;
    set y(value: number);
    get width(): number;
    set width(value: number);
    get height(): number;
    set height(value: number);
    get origin(): Point;
    set origin(value: Point);
    get size(): Size;
    set size(value: Size);
}
interface RecurrenceRuleState {
}
declare class AbsRecurrenceRule<S extends RecurrenceRuleState = RecurrenceRuleState> extends ScriptableClass<S> implements Omit<RecurrenceRule, 'recurrenceRule'> {
    static readonly identifier = "RecurrenceRule";
    /**
       * _Constructs a daily recurrence rule._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every day and a
       * value of 3 specifies that the rule should repeat every third day.
       * @param interval - Interval at which to repeat the rule.
       * @see https://docs.scriptable.app/recurrencerule/#daily
       */
    static daily(interval: number): RecurrenceRule;
    /**
       * _Constructs a daily recurrence rule with an end date._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every day and a
       * value of 3 specifies that the rule should repeat every third day.
       * @param interval - Interval at which to repeat the rule.
       * @param endDate - Date at which the recurrence rule should end.
       * @see https://docs.scriptable.app/recurrencerule/#dailyenddate
       */
    static dailyEndDate(interval: number, endDate: Date): RecurrenceRule;
    /**
       * _Constructs a daily recurrence rule with an occurrence count._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every day and a
       * value of 3 specifies that the rule should repeat every third day.
       * @param interval - Interval at which to repeat the rule.
       * @param occurrenceCount - Number of times the rule should repeat before it ends.
       * @see https://docs.scriptable.app/recurrencerule/#dailyoccurrencecount
       */
    static dailyOccurrenceCount(interval: number, occurrenceCount: number): RecurrenceRule;
    /**
       * _Constructs a weekly recurrence rule._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
       * value of 3 specifies that the rule should repeat every third week.
       * @param interval - Interval at which to repeat the rule.
       * @see https://docs.scriptable.app/recurrencerule/#weekly
       */
    static weekly(interval: number): RecurrenceRule;
    /**
       * _Constructs a weekly recurrence rule with an end date._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
       * value of 3 specifies that the rule should repeat every third week.
       * @param interval - Interval at which to repeat the rule.
       * @param endDate - Date at which the recurrence rule should end.
       * @see https://docs.scriptable.app/recurrencerule/#weeklyenddate
       */
    static weeklyEndDate(interval: number, endDate: Date): RecurrenceRule;
    /**
       * _Constructs a weekly recurrence rule with an occurrence count._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
       * value of 3 specifies that the rule should repeat every third week.
       * @param interval - Interval at which to repeat the rule.
       * @param occurrenceCount - Number of times the rule should repeat before it ends.
       * @see https://docs.scriptable.app/recurrencerule/#weeklyoccurrencecount
       */
    static weeklyOccurrenceCount(interval: number, occurrenceCount: number): RecurrenceRule;
    /**
       * _Constructs a monthly recurrence rule._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
       * value of 3 specifies that the rule should repeat every third month.
       * @param interval - Interval at which to repeat the rule.
       * @see https://docs.scriptable.app/recurrencerule/#monthly
       */
    static monthly(interval: number): RecurrenceRule;
    /**
       * _Constructs a monthly recurrence rule with an end date._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
       * value of 3 specifies that the rule should repeat every third month.
       * @param interval - Interval at which to repeat the rule.
       * @param endDate - Date at which the recurrence rule should end.
       * @see https://docs.scriptable.app/recurrencerule/#monthlyenddate
       */
    static monthlyEndDate(interval: number, endDate: Date): RecurrenceRule;
    /**
       * _Constructs a monthly recurrence rule with an occurrence count._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
       * value of 3 specifies that the rule should repeat every third month.
       * @param interval - Interval at which to repeat the rule.
       * @param occurrenceCount - Number of times the rule should repeat before it ends.
       * @see https://docs.scriptable.app/recurrencerule/#monthlyoccurrencecount
       */
    static monthlyOccurrenceCount(interval: number, occurrenceCount: number): RecurrenceRule;
    /**
       * _Constructs a yearly recurrence rule._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
       * value of 3 specifies that the rule should repeat every third year.
       * @param interval - Interval at which to repeat the rule.
       * @see https://docs.scriptable.app/recurrencerule/#yearly
       */
    static yearly(interval: number): RecurrenceRule;
    /**
       * _Constructs a yearly recurrence rule with an end date._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
       * value of 3 specifies that the rule should repeat every third year.
       * @param interval - Interval at which to repeat the rule.
       * @param endDate - Date at which the recurrence rule should end.
       * @see https://docs.scriptable.app/recurrencerule/#yearlyenddate
       */
    static yearlyEndDate(interval: number, endDate: Date): RecurrenceRule;
    /**
       * _Constructs a yearly recurrence rule with an occurrence count._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
       * value of 3 specifies that the rule should repeat every third year.
       * @param interval - Interval at which to repeat the rule.
       * @param occurrenceCount - Number of times the rule should repeat before it ends.
       * @see https://docs.scriptable.app/recurrencerule/#yearlyoccurrencecount
       */
    static yearlyOccurrenceCount(interval: number, occurrenceCount: number): RecurrenceRule;
    /**
       * _Constructs a complex weekly recurrence rule._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
       * value of 3 specifies that the rule should repeat every third week.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @see https://docs.scriptable.app/recurrencerule/#complexweekly
       */
    static complexWeekly(interval: number, daysOfTheWeek: readonly number[], setPositions: readonly number[]): RecurrenceRule;
    /**
       * _Constructs a complex weekly recurrence rule with an end date._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
       * value of 3 specifies that the rule should repeat every third week.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @param endDate - Date at which the recurrence rule should end.
       * @see https://docs.scriptable.app/recurrencerule/#complexweeklyenddate
       */
    static complexWeeklyEndDate(interval: number, daysOfTheWeek: readonly number[], setPositions: readonly number[], endDate: Date): RecurrenceRule;
    /**
       * _Constructs a complex weekly recurrence rule with an occurrence count._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every week and a
       * value of 3 specifies that the rule should repeat every third week.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @param occurrenceCount - Number of times the rule should repeat before it ends.
       * @see https://docs.scriptable.app/recurrencerule/#complexweeklyoccurrencecount
       */
    static complexWeeklyOccurrenceCount(interval: number, daysOfTheWeek: readonly number[], setPositions: readonly number[], occurrenceCount: number): RecurrenceRule;
    /**
       * _Constructs a complex monthly recurrence rule._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
       * value of 3 specifies that the rule should repeat every third month.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param daysOfTheMonth - Days of the month to repeat the rule. Values range from 1 to 31 and from -1 to -31.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @see https://docs.scriptable.app/recurrencerule/#complexmonthly
       */
    static complexMonthly(interval: number, daysOfTheWeek: readonly number[], daysOfTheMonth: readonly number[], setPositions: readonly number[]): RecurrenceRule;
    /**
       * _Constructs a complex monthly recurrence rule with an end date._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
       * value of 3 specifies that the rule should repeat every third month.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param daysOfTheMonth - Days of the month to repeat the rule. Values range from 1 to 31 and from -1 to -31.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @param endDate - Date at which the recurrence rule should end.
       * @see https://docs.scriptable.app/recurrencerule/#complexmonthlyenddate
       */
    static complexMonthlyEndDate(interval: number, daysOfTheWeek: readonly number[], daysOfTheMonth: readonly number[], setPositions: readonly number[], endDate: Date): RecurrenceRule;
    /**
       * _Constructs a complex monthly recurrence rule with an occurrence count._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every month and a
       * value of 3 specifies that the rule should repeat every third month.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param daysOfTheMonth - Days of the month to repeat the rule. Values range from 1 to 31 and from -1 to -31.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @param occurrenceCount - Number of times the rule should repeat before it ends.
       * @see https://docs.scriptable.app/recurrencerule/#complexmonthlyoccurrencecount
       */
    static complexMonthlyOccurrenceCount(interval: number, daysOfTheWeek: readonly number[], daysOfTheMonth: readonly number[], setPositions: readonly number[], occurrenceCount: number): RecurrenceRule;
    /**
       * _Constructs a complex yearly recurrence rule._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
       * value of 3 specifies that the rule should repeat every third year.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param monthsOfTheYear - The months of the year to repeat the rule. Values range from 1 to 12.
       * @param weeksOfTheYear - The weeks of the year to repeat the rule. Values range from 1 to 53 and -1 to -53.
       * @param daysOfTheYear - The days of the year to repeat the rule. Values range from 1 to 366 and -1 to -366.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @see https://docs.scriptable.app/recurrencerule/#complexyearly
       */
    static complexYearly(interval: number, daysOfTheWeek: readonly number[], monthsOfTheYear: readonly number[], weeksOfTheYear: readonly number[], daysOfTheYear: readonly number[], setPositions: readonly number[]): RecurrenceRule;
    /**
       * _Constructs a complex yearly recurrence rule with an end date._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
       * value of 3 specifies that the rule should repeat every third week.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param monthsOfTheYear - The months of the year to repeat the rule. Values range from 1 to 12.
       * @param weeksOfTheYear - The weeks of the year to repeat the rule. Values range from 1 to 53 and -1 to -53.
       * @param daysOfTheYear - The days of the year to repeat the rule. Values range from 1 to 366 and -1 to -366.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @param endDate - Date at which the recurrence rule should end.
       * @see https://docs.scriptable.app/recurrencerule/#complexyearlyenddate
       */
    static complexYearlyEndDate(interval: number, daysOfTheWeek: readonly number[], monthsOfTheYear: readonly number[], weeksOfTheYear: readonly number[], daysOfTheYear: readonly number[], setPositions: readonly number[], endDate: Date): RecurrenceRule;
    /**
       * _Constructs a complex yearly recurrence rule with an occurrence count._
       *
       * The interval should have a value greater than 0 and specifies how often the pattern repeats. For example, an interval of 1 specifies that the rule should repeat every year and a
       * value of 3 specifies that the rule should repeat every third year.
       *
       * The setPositions filters which recurrences to include in the rule's frequency. For example, a yearly recurrence rule that has a daysOfTheWeek value that specifies Monday through
       * Friday and setPositions contain 2 and -1, occurs only on the second weekday and last weekday of every year.
       * @param interval - Interval at which to repeat the rule.
       * @param daysOfTheWeek - Days of the week to repeat the rule. Values range from 1 to 7, with Sunday being 1.
       * @param monthsOfTheYear - The months of the year to repeat the rule. Values range from 1 to 12.
       * @param weeksOfTheYear - The weeks of the year to repeat the rule. Values range from 1 to 53 and -1 to -53.
       * @param daysOfTheYear - The days of the year to repeat the rule. Values range from 1 to 366 and -1 to -366.
       * @param setPositions - Filters which recurrences to include in the rule's frequency.
       * @param occurrenceCount - Number of times the rule should repeat before it ends.
       * @see https://docs.scriptable.app/recurrencerule/#complexyearlyoccurrencecount
       */
    static complexYearlyOccurrenceCount(interval: number, daysOfTheWeek: readonly number[], monthsOfTheYear: readonly number[], weeksOfTheYear: readonly number[], daysOfTheYear: readonly number[], setPositions: readonly number[], occurrenceCount: number): RecurrenceRule;
}
interface RelativeDateTimeFormatterState {
    locale: string;
}
declare class AbsRelativeDateTimeFormatter<S extends RelativeDateTimeFormatterState = RelativeDateTimeFormatterState> extends ScriptableClass<S> implements RelativeDateTimeFormatter {
    static readonly identifier = "RelativeDateTimeFormatter";
    get locale(): string;
    set locale(value: string);
    /**
       * _Creates a localized string communicating the amount of time between two dates._
       *
       * Creates a localized textual representation of the amount of time between to dates. If the two dates are the same, the function will return "now". If the reference date is
       * yesterday, the function will return "yesterday". Other examples include "in 10 seconds", "2 hours ago", "last week" and "next year".
       * @param date - The date to create a relative date and time for.
       * @param referenceDate - The reference date that `date` is relative to.
       * @see https://docs.scriptable.app/relativedatetimeformatter/#-string
       */
    string(date: Date, referenceDate: Date): string;
    /**
       * _Prefers named dates and times._
       *
       * When using the named style, the formatter tries to find a suitable textual representation over a numeric value for the relative time, e.g. "now" instead of "in 0 seconds" and
       * "yesterday" instead of "1 day ago".
       *
       * When no named representation is found the formatter will fallback to using the numeric style.
       * @see https://docs.scriptable.app/relativedatetimeformatter/#-usenameddatetimestyle
       */
    useNamedDateTimeStyle(): void;
    /**
       * _Prefers numeric dates and times._
       *
       * When using the numeric style, the formatter will always prefer numeric representations over named representations. E.g. it will return "in 0 seconds" instead of "now" and "1 day
       * ago" instead of "yesteday".
       * @see https://docs.scriptable.app/relativedatetimeformatter/#-usenumericdatetimestyle
       */
    useNumericDateTimeStyle(): void;
}
interface ReminderState {
    identifier: string;
    title: string;
    notes: string;
    isCompleted: boolean;
    isOverdue: boolean;
    priority: number;
    dueDate: Date;
    dueDateIncludesTime: boolean;
    completionDate: Date;
    creationDate: Date;
    calendar: Calendar;
}
declare class AbsReminder<S extends ReminderState = ReminderState> extends ScriptableClass<S> implements Reminder {
    static readonly identifier = "Reminder";
    /**
       * _Fetches the schedule of reminders._
       *
       * The fetched result contains reminders that are due today and reminders that are overdue. This is similar to the reminders shown in the Reminders apps "Scheduled" list. For
       * performance reasons iOS limits fetched results to events within a four year timespan.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#scheduled
       */
    static scheduled(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all reminders._
       *
       * For performance reasons iOS limits fetched results to events within a four year timespan.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#all
       */
    static all(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all completed reminders._
       *
       * For performance reasons iOS limits fetched results to events within a four year timespan.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#allcompleted
       */
    static allCompleted(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all incomplete reminders._
       *
       * For performance reasons iOS limits fetched results to events within a four year timespan.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#allincomplete
       */
    static allIncomplete(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all reminders due today._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#allduetoday
       */
    static allDueToday(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches completed reminders due today._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedduetoday
       */
    static completedDueToday(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches incomplete reminders due today._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#incompleteduetoday
       */
    static incompleteDueToday(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all reminders due tomorrow._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#allduetomorrow
       */
    static allDueTomorrow(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches completed reminders due tomorrow._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedduetomorrow
       */
    static completedDueTomorrow(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches incomplete reminders due tomorrow._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#incompleteduetomorrow
       */
    static incompleteDueTomorrow(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all reminders due yesterday._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#alldueyesterday
       */
    static allDueYesterday(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches completed reminders due yesterday._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completeddueyesterday
       */
    static completedDueYesterday(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches incomplete reminders due yesterday._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#incompletedueyesterday
       */
    static incompleteDueYesterday(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all reminders due this week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#allduethisweek
       */
    static allDueThisWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches completed reminders due this week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedduethisweek
       */
    static completedDueThisWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches incomplete reminders due this week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#incompleteduethisweek
       */
    static incompleteDueThisWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all reminders due next week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#allduenextweek
       */
    static allDueNextWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches completed reminders due next week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedduenextweek
       */
    static completedDueNextWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches incomplete reminders due next week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#incompleteduenextweek
       */
    static incompleteDueNextWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches all reminders due last week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#allduelastweek
       */
    static allDueLastWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches completed reminders due last week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedduelastweek
       */
    static completedDueLastWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches incomplete reminders due last week._
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#incompleteduelastweek
       */
    static incompleteDueLastWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches reminders completed today._
       *
       * Note that this does not take the due date into account. This will return all reminders that you have completed today.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedtoday
       */
    static completedToday(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches reminders completed this week._
       *
       * Note that this does not take the due date into account. This will return all reminders that you have completed this week.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedthisweek
       */
    static completedThisWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches reminders completed last week._
       *
       * Note that this does not take the due date into account. This will return all reminders that you have completed last week.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedlastweek
       */
    static completedLastWeek(calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches due reminders._
       *
       * Fetches reminders that are due within the time interval constituted by the start and end dates.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#allduebetween
       */
    static allDueBetween(startDate: Date, endDate: Date, calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches completed reminders._
       *
       * Fetches reminders that are completed and that were due within the time interval constituted by the start and end dates.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedduebetween
       */
    static completedDueBetween(startDate: Date, endDate: Date, calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches incomplete reminders._
       *
       * Fetches reminders that are incomplete and that were due within the time interval constituted by the start and end dates.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#incompleteduebetween
       */
    static incompleteDueBetween(startDate: Date, endDate: Date, calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
       * _Fetches completed reminders._
       *
       * Fetches reminders that were completed within the time interval constituted by the start and end dates.
       * @param calendars - Calendars to fetch reminders for. Defaults to all calendars.
       * @see https://docs.scriptable.app/reminder/#completedbetween
       */
    static completedBetween(startDate: Date, endDate: Date, calendars?: readonly Calendar[]): Promise<Reminder[]>;
    get identifier(): string;
    set identifier(value: string);
    get title(): string;
    set title(value: string);
    get notes(): string;
    set notes(value: string);
    get isCompleted(): boolean;
    set isCompleted(value: boolean);
    get isOverdue(): boolean;
    set isOverdue(value: boolean);
    get priority(): number;
    set priority(value: number);
    get dueDate(): Date;
    set dueDate(value: Date);
    get dueDateIncludesTime(): boolean;
    set dueDateIncludesTime(value: boolean);
    get completionDate(): Date;
    set completionDate(value: Date);
    get creationDate(): Date;
    set creationDate(value: Date);
    get calendar(): Calendar;
    set calendar(value: Calendar);
    /**
       * _Adds a recurrence rule._
       *
       * Recurrence rules specify when the reminder should be repeated. See the documentation of RecurrenceRule for more information on creating rules.
       * @param recurrenceRule - Recurrence rule to add to the reminder.
       * @see https://docs.scriptable.app/reminder/#-addrecurrencerule
       */
    addRecurrenceRule(recurrenceRule: RecurrenceRule): void;
    /**
       * _Removes all recurrence rules._
       * @see https://docs.scriptable.app/reminder/#-removeallrecurrencerules
       */
    removeAllRecurrenceRules(): void;
    /**
       * _Saves reminder._
       *
       * Saves changes to a reminder, inserting it into the calendar if it is newly created.
       * @see https://docs.scriptable.app/reminder/#-save
       */
    save(): void;
    /**
       * _Removes reminder from calendar._
       * @see https://docs.scriptable.app/reminder/#-remove
       */
    remove(): void;
}
interface RequestState {
    url: string;
    method: string;
    headers: {
        [key: string]: string;
    };
    body: any;
    timeoutInterval: number;
    response: {
        [key: string]: any;
    };
    allowInsecureRequest: boolean;
    onRedirect: (arg0: Request) => Request;
}
declare class AbsRequest<S extends RequestState = RequestState> extends ScriptableClass<S> implements Request {
    static readonly identifier = "Request";
    get url(): string;
    set url(value: string);
    get method(): string;
    set method(value: string);
    get headers(): {
        [key: string]: string;
    };
    set headers(value: {
        [key: string]: string;
    });
    get body(): any;
    set body(value: any);
    get timeoutInterval(): number;
    set timeoutInterval(value: number);
    get response(): {
        [key: string]: any;
    };
    set response(value: {
        [key: string]: any;
    });
    get allowInsecureRequest(): boolean;
    set allowInsecureRequest(value: boolean);
    get onRedirect(): (arg0: Request) => Request;
    set onRedirect(value: (arg0: Request) => Request);
    /**
       * _Sends request._
       *
       * Call to send the configured request to the specified URL. The raw response is provided when the returned promise is fulfilled.
       * @see https://docs.scriptable.app/request/#-load
       */
    load(): Promise<Data>;
    /**
       * _Sends request and parses response as a string._
       *
       * Call to send the configured request to the specified URL. The response is parsed to a string and provided when the returned promise is fulfilled.
       * @see https://docs.scriptable.app/request/#-loadstring
       */
    loadString(): Promise<string>;
    /**
       * _Sends request and parses response as JSON._
       *
       * Call to send the configured request to the specified URL. The response is expected to be a valid JSON string and is parsed into an object.
       * @see https://docs.scriptable.app/request/#-loadjson
       */
    loadJSON(): Promise<any>;
    /**
       * _Sends request and parses response as an image._
       *
       * Call to send the configured request to the specified URL. The response is expected to be an image.
       * @see https://docs.scriptable.app/request/#-loadimage
       */
    loadImage(): Promise<Image>;
    /**
       * _Adds a parameter to a multipart request._
       *
       * Converts the request to a multipart request and adds a parameter with the specified name and value. Be aware that the `body` property on the request is ignored for multipart
       * requests as parameters and files added to the request constitutes the body.
       *
       * Calling this function will make the request a multipart request. When the request is send, the content type will automatically be set to "multipart/form-data".
       * @param name - Name of the parameter.
       * @param value - Value of the parameter.
       * @see https://docs.scriptable.app/request/#-addparametertomultipart
       */
    addParameterToMultipart(name: string, value: string): void;
    /**
       * _Adds a file to a multipart request._
       *
       * Converts the request to a multipart request and adds the file to the request. Be aware that the `body` property on the request is ignored for multipart requests as parameters and
       * files added to the request constitutes the body.
       *
       * Calling this function will make the request a multipart request. When the request is send, the content type will automatically be set to "multipart/form-data".
       * @param data - File data to add.
       * @param mimeType - MIME type of the file to add.
       * @param name - Name of the parameter which holds the file.
       * @param filename - Name of the file.
       * @see https://docs.scriptable.app/request/#-addfiledatatomultipart
       */
    addFileDataToMultipart(data: Data, mimeType: string, name: string, filename: string): void;
    /**
       * _Adds a file to a multipart request._
       *
       * Converts the request to a multipart request and adds the file to the request. The function will automatically determine the MIME type of the file as well as the filename. Be aware
       * that the `body` property on the request is ignored for multipart requests as parameters and files added to the request constitutes the body.
       *
       * Calling this function will make the request a multipart request. When the request is send, the content type will automatically be set to "multipart/form-data".
       * @param filePath - Path of the file to add.
       * @param name - Name of the parameter which holds the file.
       * @param filename - Optional name of the uploaded file.
       * @see https://docs.scriptable.app/request/#-addfiletomultipart
       */
    addFileToMultipart(filePath: string, name: string, filename?: string): void;
    /**
       * _Adds an image to a multipart request._
       *
       * Converts the request to a multipart request and adds the image to the request. The function will automatically determine the MIME type of the file Be aware that the `body` property
       * on the request is ignored for multipart requests as parameters and files added to the request constitutes the body.
       *
       * Calling this function will make the request a multipart request. When the request is send, the content type will automatically be set to "multipart/form-data".
       * @param image - Image to add.
       * @param name - Name of the parameter which holds the file.
       * @param filename - Optional name of the uploaded file.
       * @see https://docs.scriptable.app/request/#-addimagetomultipart
       */
    addImageToMultipart(image: Image, name: string, filename?: string): void;
}
interface SFSymbolState {
    image: Image;
}
declare class AbsSFSymbol<S extends SFSymbolState = SFSymbolState> extends ScriptableClass<S> implements SFSymbol {
    static readonly identifier = "SFSymbol";
    /**
       * _Constructs an SF symbol._
       *
       * SF symbols are Apples configurable icons that are designed to look great with the San Francisco font.
       *
       * Symbols are referenced by their name. You can find the symbol names in [Apples SF Symbols app for macOS](https://developer.apple.com/sf-symbols/). You can also browse symbol names
       * in the [SF Symbols Browser](https://apps.apple.com/us/app/sf-symbols-browser/id1491161336) and [San Fransymbols](https://apps.apple.com/us/app/san-fransymbols/id1504761986) apps
       * for iOS.
       * @param symbolName - Name of the symbol.
       * @see https://docs.scriptable.app/sfsymbol/#named
       */
    static named(symbolName: string): SFSymbol;
    get image(): Image;
    set image(value: Image);
    /**
       * _Configures the symbol with the specified font information._
       * @see https://docs.scriptable.app/sfsymbol/#-applyfont
       */
    applyFont(font: Font): void;
    /**
       * _Configures the symbol to use an ultra light weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applyultralightweight
       */
    applyUltraLightWeight(): void;
    /**
       * _Configures the symbol to use a thin weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applythinweight
       */
    applyThinWeight(): void;
    /**
       * _Configures the symbol to use a light weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applylightweight
       */
    applyLightWeight(): void;
    /**
       * _Configures the symbol to use a regular weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applyregularweight
       */
    applyRegularWeight(): void;
    /**
       * _Configures the symbol to use a medium weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applymediumweight
       */
    applyMediumWeight(): void;
    /**
       * _Configures the symbol to use a semibold weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applysemiboldweight
       */
    applySemiboldWeight(): void;
    /**
       * _Configures the symbol to use a bold weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applyboldweight
       */
    applyBoldWeight(): void;
    /**
       * _Configures the symbol to use a heavy weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applyheavyweight
       */
    applyHeavyWeight(): void;
    /**
       * _Configures the symbol to use a black weight._
       * @see https://docs.scriptable.app/sfsymbol/#-applyblackweight
       */
    applyBlackWeight(): void;
}
interface SizeState {
    width: number;
    height: number;
}
declare class AbsSize<S extends SizeState = SizeState> extends ScriptableClass<S> implements Size {
    static readonly identifier = "Size";
    get width(): number;
    set width(value: number);
    get height(): number;
    set height(value: number);
}
interface TextFieldState {
    text: string;
    placeholder: string;
    isSecure: boolean;
    textColor: Color;
    font: Font;
}
declare class AbsTextField<S extends TextFieldState = TextFieldState> extends ScriptableClass<S> implements TextField {
    static readonly identifier = "TextField";
    get text(): string;
    set text(value: string);
    get placeholder(): string;
    set placeholder(value: string);
    get isSecure(): boolean;
    set isSecure(value: boolean);
    get textColor(): Color;
    set textColor(value: Color);
    get font(): Font;
    set font(value: Font);
    /**
       * _Use the default keyboard for entering text._
       * @see https://docs.scriptable.app/textfield/#-setdefaultkeyboard
       */
    setDefaultKeyboard(): void;
    /**
       * _Use a keyboard that prominently features the numbers 0 through 9._
       * @see https://docs.scriptable.app/textfield/#-setnumberpadkeyboard
       */
    setNumberPadKeyboard(): void;
    /**
       * _Use a numeric keyboard with a decimal point for entering text._
       * @see https://docs.scriptable.app/textfield/#-setdecimalpadkeyboard
       */
    setDecimalPadKeyboard(): void;
    /**
       * _Use a numeric keyboard with punctuation for entering text._
       * @see https://docs.scriptable.app/textfield/#-setnumbersandpunctuationkeyboard
       */
    setNumbersAndPunctuationKeyboard(): void;
    /**
       * _Use a keyboard that prominently features the numbers 0 through 9 and the * and # characters._
       * @see https://docs.scriptable.app/textfield/#-setphonepadkeyboard
       */
    setPhonePadKeyboard(): void;
    /**
       * _Use a keyboard that prominently features the space and period characters._
       * @see https://docs.scriptable.app/textfield/#-setwebsearchkeyboard
       */
    setWebSearchKeyboard(): void;
    /**
       * _Use a keyboard that prominently features the @, period and space characters._
       * @see https://docs.scriptable.app/textfield/#-setemailaddresskeyboard
       */
    setEmailAddressKeyboard(): void;
    /**
       * _Use a keyboard that prominently features the period and slash characters and the ".com" string._
       * @see https://docs.scriptable.app/textfield/#-seturlkeyboard
       */
    setURLKeyboard(): void;
    /**
       * _Use a keyboard that prominently features the @ and # characters._
       * @see https://docs.scriptable.app/textfield/#-settwitterkeyboard
       */
    setTwitterKeyboard(): void;
    /**
       * _Left aligns the text._
       *
       * This is the default text alignment.
       * @see https://docs.scriptable.app/textfield/#-leftaligntext
       */
    leftAlignText(): void;
    /**
       * _Center aligns the text._
       * @see https://docs.scriptable.app/textfield/#-centeraligntext
       */
    centerAlignText(): void;
    /**
       * _Right aligns the text._
       * @see https://docs.scriptable.app/textfield/#-rightaligntext
       */
    rightAlignText(): void;
}
interface TimerState {
    timeInterval: number;
    repeats: boolean;
}
declare class AbsTimer<S extends TimerState = TimerState> extends ScriptableClass<S> implements Timer {
    static readonly identifier = "Timer";
    /**
       * _Schedules a timer._
       *
       * This is a convenience function for creating a new timer. The created timer is instantly scheduled and will fire after the specified time interval.
       * @param timeInterval - The time interval to fire the timer at.
       * @param repeats - Whether the timer should repeat or not.
       * @param callback - The callback to be called when the timer fires.
       * @see https://docs.scriptable.app/timer/#schedule
       */
    static schedule(timeInterval: number, repeats: boolean, callback: () => void): Timer;
    get timeInterval(): number;
    set timeInterval(value: number);
    get repeats(): boolean;
    set repeats(value: boolean);
    /**
       * _Schedules the timer._
       *
       * Schedules the timer using its configuration. The supplied function is called when the timer fires. To stop the timer from firing, call the `invalidate()` function.
       * @param callback - The callback to be called when the timer fires.
       * @see https://docs.scriptable.app/timer/#-schedule
       */
    schedule(callback: () => void): void;
    /**
       * _Stops the timer from firing._
       *
       * Stops the timer from firing ever again. Non-repeating timers are automatically invalidated after they have fired once. Repeating timers must be manually invalidated.
       * @see https://docs.scriptable.app/timer/#-invalidate
       */
    invalidate(): void;
}
interface UITableState {
    showSeparators: boolean;
}
declare class AbsUITable<S extends UITableState = UITableState> extends ScriptableClass<S> implements UITable {
    static readonly identifier = "UITable";
    get showSeparators(): boolean;
    set showSeparators(value: boolean);
    /**
       * _Adds a row._
       *
       * Adds a row to the table. Rows are shown vertically in the table view, i.e. from the top and down. Rows are rendered in the order they are added.
       * @param row - Row to add.
       * @see https://docs.scriptable.app/uitable/#-addrow
       */
    addRow(row: UITableRow): void;
    /**
       * _Removes a row._
       *
       * Removes a row from the table.
       * @param row - Row to remove.
       * @see https://docs.scriptable.app/uitable/#-removerow
       */
    removeRow(row: UITableRow): void;
    /**
       * _Removes all rows._
       *
       * Removes all rows from the table. If the table is presented, you must call the `reload` function in order for the changes to be reflected visually.
       * @see https://docs.scriptable.app/uitable/#-removeallrows
       */
    removeAllRows(): void;
    /**
       * _Reloads the table._
       *
       * If you add or remove rows while a table view is presented, you must reload the table in order for the changes to take effect.
       * @see https://docs.scriptable.app/uitable/#-reload
       */
    reload(): void;
    /**
       * _Presents the table._
       * @param fullscreen - Optional. Set to true to present the web view in fullscreen. This only has an effect when used within the app. Defaults to false.
       * @see https://docs.scriptable.app/uitable/#-present
       */
    present(fullscreen?: boolean): Promise<void>;
}
interface UITableCellState {
    widthWeight: number;
    dismissOnTap: boolean;
    titleColor: Color;
    subtitleColor: Color;
    titleFont: Font;
    subtitleFont: Font;
    onTap: () => void;
}
declare class AbsUITableCell<S extends UITableCellState = UITableCellState> extends ScriptableClass<S> implements UITableCell {
    static readonly identifier = "UITableCell";
    /**
       * _Constructs a text cell._
       *
       * Constructs a new cell containing text.
       * @param title - Optional title to show in the cell.
       * @param subtitle - Optional subtitle shown below the title.
       * @see https://docs.scriptable.app/uitablecell/#text
       */
    static text(title?: string, subtitle?: string): UITableCell;
    /**
       * _Constructs an image cell._
       *
       * Constructs a new cell containing an image.
       * @param image - Image to show in the cell.
       * @see https://docs.scriptable.app/uitablecell/#image
       */
    static image(image: Image): UITableCell;
    /**
       * _Constructs an image cell._
       *
       * Constructs a new cell that loads the image at the specified URL.
       * @param url - URL to image.
       * @see https://docs.scriptable.app/uitablecell/#imageaturl
       */
    static imageAtURL(url: string): UITableCell;
    /**
       * _Constructs a button cell._
       *
       * Constructs a new cell that contains a button. Set the `onTap` property to specify an action to performed when the button is tapped.
       * @param title - Title of the button.
       * @see https://docs.scriptable.app/uitablecell/#button
       */
    static button(title: string): UITableCell;
    get widthWeight(): number;
    set widthWeight(value: number);
    get dismissOnTap(): boolean;
    set dismissOnTap(value: boolean);
    get titleColor(): Color;
    set titleColor(value: Color);
    get subtitleColor(): Color;
    set subtitleColor(value: Color);
    get titleFont(): Font;
    set titleFont(value: Font);
    get subtitleFont(): Font;
    set subtitleFont(value: Font);
    get onTap(): () => void;
    set onTap(value: () => void);
    /**
       * _Left aligns content._
       *
       * Specifies that the content in the cell should be left aligned.
       * @see https://docs.scriptable.app/uitablecell/#-leftaligned
       */
    leftAligned(): void;
    /**
       * _Center aligns content._
       *
       * Specifies that the content in the cell should be center aligned.
       * @see https://docs.scriptable.app/uitablecell/#-centeraligned
       */
    centerAligned(): void;
    /**
       * _Right aligns content._
       *
       * Specifies that the content in the cell should be right aligned.
       * @see https://docs.scriptable.app/uitablecell/#-rightaligned
       */
    rightAligned(): void;
}
interface UITableRowState {
    cellSpacing: number;
    height: number;
    isHeader: boolean;
    dismissOnSelect: boolean;
    backgroundColor: Color;
    onSelect: () => void;
}
declare class AbsUITableRow<S extends UITableRowState = UITableRowState> extends ScriptableClass<S> implements UITableRow {
    static readonly identifier = "UITableRow";
    get cellSpacing(): number;
    set cellSpacing(value: number);
    get height(): number;
    set height(value: number);
    get isHeader(): boolean;
    set isHeader(value: boolean);
    get dismissOnSelect(): boolean;
    set dismissOnSelect(value: boolean);
    get backgroundColor(): Color;
    set backgroundColor(value: Color);
    get onSelect(): () => void;
    set onSelect(value: () => void);
    /**
       * _Adds a cell._
       *
       * Adds a cell to the row. Note that cells are shown in the order they are added to the row.
       * @param cell - Cell to add to the row.
       * @see https://docs.scriptable.app/uitablerow/#-addcell
       */
    addCell(cell: UITableCell): void;
    /**
       * _Adds a text cell._
       *
       * Constructs a new cell containing the specified string and adds it to the row.
       * @param title - Optional title to show in the cell.
       * @param subtitle - Optional subtitle shown below the title in the cell.
       * @see https://docs.scriptable.app/uitablerow/#-addtext
       */
    addText(title?: string, subtitle?: string): UITableCell;
    /**
       * _Adds an image cell._
       *
       * Constructs a new cell containing the specified image and adds it to the row.
       * @param image - Image to show in the cell.
       * @see https://docs.scriptable.app/uitablerow/#-addimage
       */
    addImage(image: Image): UITableCell;
    /**
       * _Adds an image cell._
       *
       * Constructs a new cell that loads the image at the specified url and adds the cell to the row.
       * @param url - URL to image.
       * @see https://docs.scriptable.app/uitablerow/#-addimageaturl
       */
    addImageAtURL(url: string): UITableCell;
    /**
       * _Adds a button cell._
       *
       * Constructs a new cell that contains a button. Set the `onTap` property to specify an action to performed when the button is tapped.
       * @param title - Title of the button.
       * @see https://docs.scriptable.app/uitablerow/#-addbutton
       */
    addButton(title: string): UITableCell;
}
interface WebViewState {
    shouldAllowRequest: (arg0: Request) => boolean;
}
declare class AbsWebView<S extends WebViewState = WebViewState> extends ScriptableClass<S> implements WebView {
    static readonly identifier = "WebView";
    /**
       * _Loads HTML and renders it._
       * @param html - HTML to load and render.
       * @param baseURL - Optional. Base URL used to resolve relative URLs in the HTML.
       * @param preferredSize - Optional. Preferred size of the view. This size is not guaranteed to be respected and is only used when the script is run with Siri or in the Shortcuts app.
       * @param fullscreen - Optional. Set to true to present the web view in fullscreen. This only has an effect when used within the app. Defaults to false.
       * @see https://docs.scriptable.app/webview/#loadhtml
       */
    static loadHTML(html: string, baseURL?: string, preferredSize?: Size, fullscreen?: boolean): Promise<void>;
    /**
       * _Loads a file and renders it._
       *
       * Files can be of various types, including HTML files and images.
       *
       * The supplied HTML file can reference files and nested directories in the same directory as the HTML file resides.
       *
       * The optional `preferredSize` parameter is ignored unless the script is run in a Siri Shortcut.
       *
       * If you are displaying large images in a memory constrained envrionment, for example in a Siri Shortcut, you should use the WebView bridge instead of the QuickLook bridge. The
       * technical reason for this is that a Siri Shortcut and other app extension processes have very limited memory and loading a very large image will cause the app extension to be
       * terminated. However, the web view will run in a different process meaning that it is not affected by the same memory constraints.
       * @param fileURL - URL of the file to load and render.
       * @param preferredSize - Optional. Preferred size of the view. This size is not guaranteed to be respected and is only used when the script is run with Siri or in the Shortcuts app.
       * @param fullscreen - Optional. Set to true to present the web view in fullscreen. This only has an effect when used within the app. Defaults to false.
       * @see https://docs.scriptable.app/webview/#loadfile
       */
    static loadFile(fileURL: string, preferredSize?: Size, fullscreen?: boolean): Promise<void>;
    /**
       * _Loads URL in web view and presents the web view._
       *
       * The optional `preferredSize` parameter is ignored unless the script is run in a Siri Shortcut.
       * @param url - URL to load into the web view.
       * @param preferredSize - Optional. Preferred size of the view. This size is not guaranteed to be respected and is only used when the script is run with Siri or in the Shortcuts app.
       * @param fullscreen - Optional. Set to true to present the web view in fullscreen. This only has an effect when used within the app. Defaults to false.
       * @see https://docs.scriptable.app/webview/#loadurl
       */
    static loadURL(url: string, preferredSize?: Size, fullscreen?: boolean): Promise<void>;
    get shouldAllowRequest(): (arg0: Request) => boolean;
    set shouldAllowRequest(value: (arg0: Request) => boolean);
    /**
       * _Loads URL in web view._
       *
       * Loads the URL in the web view. The returned promise will complete once the web view has finished loading.
       * @param url - URL to load into the web view.
       * @see https://docs.scriptable.app/webview/#-loadurl
       */
    loadURL(url: string): Promise<void>;
    /**
       * _Loads request in web view._
       *
       * When loading a request into the web view, the HTTP method, body and headers of the request will be respected. The onRedirect function on the request will not be invoked.
       * @param request - Request to load into the web view.
       * @see https://docs.scriptable.app/webview/#-loadrequest
       */
    loadRequest(request: Request): Promise<void>;
    /**
       * _Loads HTML in web view._
       *
       * Loads the HTML into the web view. The returned promise will complete once the web view has finished loading.
       * @param html - HTML to load into the web view.
       * @param baseURL - Optional. Base URL used to resolve relative URLs in the HTML.
       * @see https://docs.scriptable.app/webview/#-loadhtml
       */
    loadHTML(html: string, baseURL?: string): Promise<void>;
    /**
       * _Loads file in the web view._
       *
       * Files can be of various types, including HTML files and images.
       *
       * The supplied HTML file can reference files and nested directories in the same directory as the HTML file resides.
       * @param fileURL - URL of the file to load and render.
       * @see https://docs.scriptable.app/webview/#-loadfile
       */
    loadFile(fileURL: string): Promise<void>;
    /**
       * _Evaluates JavaScript in the web view._
       *
       * Evaluates JavaScript in the current context of the web view. The returned promise carries the result of evaluating the JavaScript.
       *
       * When passing `false` to the `useCallback` parameter, which is the default value, evaluation will terminate after evaluating the last line of the JavaScript. The value on the last
       * line of the script will be carried by the promise returned by `evaluateJavaScript`.
       *
       * When passing `true` to the `useCallback` parameter, evaluation will only complete after the globally available `completion` function is called. Any value passed to the function,
       * will be carried by the promise returned by `evaluateJavaScript`.
       *
       * The log is available from the evaluated JavaScript, i.e. messages passed to the globally available `log` and `logError` functions will be shown in the log.
       * @param javaScript - JavaScript to evaluate in the web view.
       * @param useCallback - Optional. If true the web view waits for the globally available completion function of the web view to be called before terminating. Defaults to false.
       * @see https://docs.scriptable.app/webview/#-evaluatejavascript
       */
    evaluateJavaScript(javaScript: string, useCallback?: boolean): Promise<any>;
    /**
       * _Reads and returns HTML from the loaded website._
       * @see https://docs.scriptable.app/webview/#-gethtml
       */
    getHTML(): Promise<any>;
    /**
       * _Presents the web view._
       *
       * The web view is presented with the content that has been loaded into it.
       * @param fullscreen - Set to true to present the web view in fullscreen. Defaults to false.
       * @see https://docs.scriptable.app/webview/#-present
       */
    present(fullscreen?: boolean): Promise<void>;
    /**
       * _Waits for the web view to load._
       *
       * The returned promise will be fulfilled when the web view finishes loading. If the load fails, the promise will be fulfilled with an error. Use this with caution. If the web view is
       * not loading a new page or is not about to load a new page, the returned promise will never be fulfilled. This limitation exists because Scriptable cannot determine if a web view is
       * about to load a page in cases where evaluating JavaScript in the web view causes a new page to load.
       *
       * Generally this should only be used when loading causing a new page to load from `evaluateJavaScript`. In other cases, e.g. when loading a URL using `loadURL`, the returned promise
       * will be fulfilled when the page has been loaded.
       * @see https://docs.scriptable.app/webview/#-waitforload
       */
    waitForLoad(): Promise<any>;
}
interface WidgetDateState {
    date: Date;
    textColor: Color;
    font: Font;
    textOpacity: number;
    lineLimit: number;
    minimumScaleFactor: number;
    shadowColor: Color;
    shadowRadius: number;
    shadowOffset: Point;
    url: string;
}
declare class AbsWidgetDate<S extends WidgetDateState = WidgetDateState> extends ScriptableClass<S> implements WidgetDate {
    static readonly identifier = "WidgetDate";
    get date(): Date;
    set date(value: Date);
    get textColor(): Color;
    set textColor(value: Color);
    get font(): Font;
    set font(value: Font);
    get textOpacity(): number;
    set textOpacity(value: number);
    get lineLimit(): number;
    set lineLimit(value: number);
    get minimumScaleFactor(): number;
    set minimumScaleFactor(value: number);
    get shadowColor(): Color;
    set shadowColor(value: Color);
    get shadowRadius(): number;
    set shadowRadius(value: number);
    get shadowOffset(): Point;
    set shadowOffset(value: Point);
    get url(): string;
    set url(value: string);
    /**
       * _Left aligns the text._
       *
       * Specifies that text should be left aligned. This is the default.
       *
       * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text to left in a horizontal stack, you should place a spacer after the
       * text.
       * @see https://docs.scriptable.app/widgetdate/#-leftaligntext
       */
    leftAlignText(): void;
    /**
       * _Center aligns the text._
       *
       * Specifies that text should be center aligned.
       *
       * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text in the center of a horizontal stack, you should place a spacer both
       * before and after the text.
       * @see https://docs.scriptable.app/widgetdate/#-centeraligntext
       */
    centerAlignText(): void;
    /**
       * _Right aligns the text._
       *
       * Specifies that text should be right aligned.
       *
       * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text to the right in a horizontal stack, you should place a spacer
       * before the text.
       * @see https://docs.scriptable.app/widgetdate/#-rightaligntext
       */
    rightAlignText(): void;
    /**
       * _Display time component of the date._
       *
       * Example output: 11:23PM
       * @see https://docs.scriptable.app/widgetdate/#-applytimestyle
       */
    applyTimeStyle(): void;
    /**
       * _Display entire date._
       *
       * Example output: June 3, 2019
       *
       * This is the default.
       * @see https://docs.scriptable.app/widgetdate/#-applydatestyle
       */
    applyDateStyle(): void;
    /**
       * _Display date as relative to now._
       *
       * Example output: 2 hours, 23 minutes 1 year, 1 month
       * @see https://docs.scriptable.app/widgetdate/#-applyrelativestyle
       */
    applyRelativeStyle(): void;
    /**
       * _Display date as offset from now._
       *
       * Example output: +2 hours -3 months
       * @see https://docs.scriptable.app/widgetdate/#-applyoffsetstyle
       */
    applyOffsetStyle(): void;
    /**
       * _Display date as timer counting from now._
       *
       * Example output: 2:32 36:59:01
       * @see https://docs.scriptable.app/widgetdate/#-applytimerstyle
       */
    applyTimerStyle(): void;
}
interface WidgetImageState {
    image: Image;
    resizable: boolean;
    imageSize: Size;
    imageOpacity: number;
    cornerRadius: number;
    borderWidth: number;
    borderColor: Color;
    containerRelativeShape: boolean;
    tintColor: Color;
    url: string;
}
declare class AbsWidgetImage<S extends WidgetImageState = WidgetImageState> extends ScriptableClass<S> implements WidgetImage {
    static readonly identifier = "WidgetImage";
    get image(): Image;
    set image(value: Image);
    get resizable(): boolean;
    set resizable(value: boolean);
    get imageSize(): Size;
    set imageSize(value: Size);
    get imageOpacity(): number;
    set imageOpacity(value: number);
    get cornerRadius(): number;
    set cornerRadius(value: number);
    get borderWidth(): number;
    set borderWidth(value: number);
    get borderColor(): Color;
    set borderColor(value: Color);
    get containerRelativeShape(): boolean;
    set containerRelativeShape(value: boolean);
    get tintColor(): Color;
    set tintColor(value: Color);
    get url(): string;
    set url(value: string);
    /**
       * _Left aligns the image._
       *
       * Specifies that image should be left aligned. This is the default.
       * @see https://docs.scriptable.app/widgetimage/#-leftalignimage
       */
    leftAlignImage(): void;
    /**
       * _Center aligns the image._
       *
       * Specifies that image should be center aligned.
       * @see https://docs.scriptable.app/widgetimage/#-centeralignimage
       */
    centerAlignImage(): void;
    /**
       * _Right aligns the image._
       *
       * Specifies that image should be right aligned.
       * @see https://docs.scriptable.app/widgetimage/#-rightalignimage
       */
    rightAlignImage(): void;
    /**
       * _Uses fitting content mode._
       *
       * The image will fit the available space. This content mode is the default.
       * @see https://docs.scriptable.app/widgetimage/#-applyfittingcontentmode
       */
    applyFittingContentMode(): void;
    /**
       * _Uses filling content mode._
       *
       * The image will fill the available space.
       * @see https://docs.scriptable.app/widgetimage/#-applyfillingcontentmode
       */
    applyFillingContentMode(): void;
}
interface WidgetSpacerState {
    length: number;
}
declare class AbsWidgetSpacer<S extends WidgetSpacerState = WidgetSpacerState> extends ScriptableClass<S> implements WidgetSpacer {
    static readonly identifier = "WidgetSpacer";
    get length(): number;
    set length(value: number);
}
interface WidgetStackState {
    backgroundColor: Color;
    backgroundImage: Image;
    backgroundGradient: LinearGradient;
    spacing: number;
    size: Size;
    cornerRadius: number;
    borderWidth: number;
    borderColor: Color;
    url: string;
}
declare class AbsWidgetStack<S extends WidgetStackState = WidgetStackState> extends ScriptableClass<S> implements WidgetStack {
    static readonly identifier = "WidgetStack";
    get backgroundColor(): Color;
    set backgroundColor(value: Color);
    get backgroundImage(): Image;
    set backgroundImage(value: Image);
    get backgroundGradient(): LinearGradient;
    set backgroundGradient(value: LinearGradient);
    get spacing(): number;
    set spacing(value: number);
    get size(): Size;
    set size(value: Size);
    get cornerRadius(): number;
    set cornerRadius(value: number);
    get borderWidth(): number;
    set borderWidth(value: number);
    get borderColor(): Color;
    set borderColor(value: Color);
    get url(): string;
    set url(value: string);
    /**
       * _Add text to the stack._
       *
       * Adds a text element to the stack. Use the properties on the returned element to style the text.
       * @see https://docs.scriptable.app/widgetstack/#-addtext
       */
    addText(text: string): WidgetText;
    /**
       * _Add date to the widget._
       *
       * Adds a date element to the widget. Use the properties on the returned element to style the date.
       * @see https://docs.scriptable.app/widgetstack/#-adddate
       */
    addDate(date: Date): WidgetDate;
    /**
       * _Add image to the stack._
       *
       * Adds an image element to the stack. Use the properties on the returned element to style the image.
       * @see https://docs.scriptable.app/widgetstack/#-addimage
       */
    addImage(image: Image): WidgetImage;
    /**
       * _Add spacer._
       *
       * Adds a spacer to the stack. This can be used to offset the content horizontally in the stack.
       * @param length - Length of the spacer. Pass null to create a spacer with a flexible length.
       * @see https://docs.scriptable.app/widgetstack/#-addspacer
       */
    addSpacer(length?: number): WidgetSpacer;
    /**
       * _Add stack._
       *
       * Adds a stack to the widget. Stacks layout elements horizontally by default.
       * @see https://docs.scriptable.app/widgetstack/#-addstack
       */
    addStack(): WidgetStack;
    /**
       * _Set padding._
       *
       * Sets the padding on each side of the stack.
       * @param top - Padding on the top edge.
       * @param leading - Padding on the leading edge.
       * @param bottom - Padding on the bottom edge.
       * @param trailing - Padding on the trailing edge.
       * @see https://docs.scriptable.app/widgetstack/#-setpadding
       */
    setPadding(top: number, leading: number, bottom: number, trailing: number): void;
    /**
       * _Use the default padding._
       *
       * Configure the stack to use the default padding. Any padding previously defined with `setPadding()` will be discarded.
       * @see https://docs.scriptable.app/widgetstack/#-usedefaultpadding
       */
    useDefaultPadding(): void;
    /**
       * _Top aligns the content._
       *
       * Specifies that the content should be top aligned. This is the default.
       * @see https://docs.scriptable.app/widgetstack/#-topaligncontent
       */
    topAlignContent(): void;
    /**
       * _Center aligns the content._
       *
       * Specifies that the content should be center aligned.
       * @see https://docs.scriptable.app/widgetstack/#-centeraligncontent
       */
    centerAlignContent(): void;
    /**
       * _Bottom aligns the content._
       *
       * Specifies that the content should be bottom aligned.
       * @see https://docs.scriptable.app/widgetstack/#-bottomaligncontent
       */
    bottomAlignContent(): void;
    /**
       * _Layout elements horizontally._
       *
       * Specifies that the stack should layout elements horizontally. This is the default.
       * @see https://docs.scriptable.app/widgetstack/#-layouthorizontally
       */
    layoutHorizontally(): void;
    /**
       * _Layout elements vertically._
       *
       * Specifies that the stack should layout elements vertically.
       * @see https://docs.scriptable.app/widgetstack/#-layoutvertically
       */
    layoutVertically(): void;
}
interface WidgetTextState {
    text: string;
    textColor: Color;
    font: Font;
    textOpacity: number;
    lineLimit: number;
    minimumScaleFactor: number;
    shadowColor: Color;
    shadowRadius: number;
    shadowOffset: Point;
    url: string;
}
declare class AbsWidgetText<S extends WidgetTextState = WidgetTextState> extends ScriptableClass<S> implements WidgetText {
    static readonly identifier = "WidgetText";
    get text(): string;
    set text(value: string);
    get textColor(): Color;
    set textColor(value: Color);
    get font(): Font;
    set font(value: Font);
    get textOpacity(): number;
    set textOpacity(value: number);
    get lineLimit(): number;
    set lineLimit(value: number);
    get minimumScaleFactor(): number;
    set minimumScaleFactor(value: number);
    get shadowColor(): Color;
    set shadowColor(value: Color);
    get shadowRadius(): number;
    set shadowRadius(value: number);
    get shadowOffset(): Point;
    set shadowOffset(value: Point);
    get url(): string;
    set url(value: string);
    /**
       * _Left aligns the text._
       *
       * Specifies that text should be left aligned. This is the default.
       *
       * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text to left in a horizontal stack, you should place a spacer after the
       * text.
       * @see https://docs.scriptable.app/widgettext/#-leftaligntext
       */
    leftAlignText(): void;
    /**
       * _Center aligns the text._
       *
       * Specifies that text should be center aligned.
       *
       * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text in the center of a horizontal stack, you should place a spacer both
       * before and after the text.
       * @see https://docs.scriptable.app/widgettext/#-centeraligntext
       */
    centerAlignText(): void;
    /**
       * _Right aligns the text._
       *
       * Specifies that text should be right aligned.
       *
       * This does not affect texts placed in stacks. Use spacers instead when aligning text in stacks. To align the text to the right in a horizontal stack, you should place a spacer
       * before the text.
       * @see https://docs.scriptable.app/widgettext/#-rightaligntext
       */
    rightAlignText(): void;
}
interface XMLParserState {
    string: string;
    didStartDocument: () => void;
    didEndDocument: () => void;
    didStartElement: (arg0: string, arg1: {
        [key: string]: string;
    }) => void;
    didEndElement: (name: string) => void;
    foundCharacters: (str: string) => void;
    parseErrorOccurred: (error: string) => void;
}
declare class AbsXMLParser<S extends XMLParserState = XMLParserState> extends ScriptableClass<S> implements XMLParser {
    static readonly identifier = "XMLParser";
    get string(): string;
    set string(value: string);
    get didStartDocument(): () => void;
    set didStartDocument(value: () => void);
    get didEndDocument(): () => void;
    set didEndDocument(value: () => void);
    get didStartElement(): (arg0: string, arg1: {
        [key: string]: string;
    }) => void;
    set didStartElement(value: (arg0: string, arg1: {
        [key: string]: string;
    }) => void);
    get didEndElement(): (name: string) => void;
    set didEndElement(value: (name: string) => void);
    get foundCharacters(): (str: string) => void;
    set foundCharacters(value: (str: string) => void);
    get parseErrorOccurred(): (error: string) => void;
    set parseErrorOccurred(value: (error: string) => void);
    /**
       * _Starts parsing._
       *
       * Before calling this function you should ensure that the parser is correctly configured, i.e. the necessary callback functions should be set.
       * @see https://docs.scriptable.app/xmlparser/#-parse
       */
    parse(): boolean;
}
/** Properties interface for global variable `args` */
interface ArgsState {
    plainTexts: string[];
    urls: string[];
    fileURLs: string[];
    images: Image[];
    queryParameters: {
        [key: string]: string;
    };
    shortcutParameter: any;
    widgetParameter: any;
    notification: Notification;
}
/** Type definition for global variable `args` */
type Args = typeof args;
/** Abstract class for global variable `args` */
declare class AbsArgs<S extends ArgsState = ArgsState> extends ScriptableVariable<S> implements Args {
    static readonly identifier = "args";
    static get instance(): AbsArgs<ArgsState>;
    get plainTexts(): string[];
    set plainTexts(value: string[]);
    get urls(): string[];
    set urls(value: string[]);
    get fileURLs(): string[];
    set fileURLs(value: string[]);
    get images(): Image[];
    set images(value: Image[]);
    get queryParameters(): {
        [key: string]: string;
    };
    set queryParameters(value: {
        [key: string]: string;
    });
    get shortcutParameter(): any;
    set shortcutParameter(value: any);
    get widgetParameter(): any;
    set widgetParameter(value: any);
    get notification(): Notification;
    set notification(value: Notification);
}
/** Properties interface for global variable `config` */
interface ConfigState {
    runsInApp: boolean;
    runsInActionExtension: boolean;
    runsWithSiri: boolean;
    runsInWidget: boolean;
    runsInAccessoryWidget: boolean;
    runsInNotification: boolean;
    runsFromHomeScreen: boolean;
    widgetFamily: "small" | "medium" | "large" | "extraLarge" | "accessoryRectangular" | "accessoryInline" | "accessoryCircular";
}
/** Type definition for global variable `config` */
type Config = typeof config;
/** Abstract class for global variable `config` */
declare class AbsConfig<S extends ConfigState = ConfigState> extends ScriptableVariable<S> implements Config {
    static readonly identifier = "config";
    static get instance(): AbsConfig<ConfigState>;
    get runsInApp(): boolean;
    set runsInApp(value: boolean);
    get runsInActionExtension(): boolean;
    set runsInActionExtension(value: boolean);
    get runsWithSiri(): boolean;
    set runsWithSiri(value: boolean);
    get runsInWidget(): boolean;
    set runsInWidget(value: boolean);
    get runsInAccessoryWidget(): boolean;
    set runsInAccessoryWidget(value: boolean);
    get runsInNotification(): boolean;
    set runsInNotification(value: boolean);
    get runsFromHomeScreen(): boolean;
    set runsFromHomeScreen(value: boolean);
    get widgetFamily(): "small" | "medium" | "large" | "extraLarge" | "accessoryRectangular" | "accessoryInline" | "accessoryCircular";
    set widgetFamily(value: "small" | "medium" | "large" | "extraLarge" | "accessoryRectangular" | "accessoryInline" | "accessoryCircular");
}
/** Properties interface for global variable `console` */
interface ConsoleState {
}
/** Type definition for global variable `console` */
type Console = typeof console;
/** Abstract class for global variable `console` */
declare class AbsConsole<S extends ConsoleState = ConsoleState> extends ScriptableVariable<S> implements Console {
    static readonly identifier = "console";
    static get instance(): AbsConsole<ConsoleState>;
    log(message: any): void;
    warn(message: any): void;
    error(message: any): void;
}
/** Properties interface for global variable `Device` */
interface DeviceState {
}
/** Type definition for global variable `Device` */
type Device = typeof Device;
/** Abstract class for global variable `Device` */
declare class AbsDevice<S extends DeviceState = DeviceState> extends ScriptableVariable<S> implements Device {
    static readonly identifier = "Device";
    static get instance(): AbsDevice<DeviceState>;
    name(): string;
    systemName(): string;
    systemVersion(): string;
    model(): string;
    isPhone(): boolean;
    isPad(): boolean;
    screenSize(): Size;
    screenResolution(): Size;
    screenScale(): number;
    screenBrightness(): number;
    isInPortrait(): boolean;
    isInPortraitUpsideDown(): boolean;
    isInLandscapeLeft(): boolean;
    isInLandscapeRight(): boolean;
    isFaceUp(): boolean;
    isFaceDown(): boolean;
    batteryLevel(): number;
    isDischarging(): boolean;
    isCharging(): boolean;
    isFullyCharged(): boolean;
    preferredLanguages(): string[];
    locale(): string;
    language(): string;
    isUsingDarkAppearance(): boolean;
    volume(): number;
    setScreenBrightness(percentage: number): void;
}
/** Properties interface for global variable `Dictation` */
interface DictationState {
}
/** Type definition for global variable `Dictation` */
type Dictation = typeof Dictation;
/** Abstract class for global variable `Dictation` */
declare class AbsDictation<S extends DictationState = DictationState> extends ScriptableVariable<S> implements Dictation {
    static readonly identifier = "Dictation";
    static get instance(): AbsDictation<DictationState>;
    start(locale?: string): Promise<string>;
}
/** Properties interface for global variable `DocumentPicker` */
interface DocumentPickerState {
}
/** Type definition for global variable `DocumentPicker` */
type DocumentPicker = typeof DocumentPicker;
/** Abstract class for global variable `DocumentPicker` */
declare class AbsDocumentPicker<S extends DocumentPickerState = DocumentPickerState> extends ScriptableVariable<S> implements DocumentPicker {
    static readonly identifier = "DocumentPicker";
    static get instance(): AbsDocumentPicker<DocumentPickerState>;
    open(types?: readonly string[]): Promise<string[]>;
    openFile(): Promise<string>;
    openFolder(): Promise<string>;
    export(path: string): Promise<string[]>;
    exportString(content: string, name?: string): Promise<string[]>;
    exportImage(image: Image, name?: string): Promise<string[]>;
    exportData(data: Data, name?: string): Promise<string[]>;
}
/** Properties interface for global variable `Keychain` */
interface KeychainState {
}
/** Type definition for global variable `Keychain` */
type Keychain = typeof Keychain;
/** Abstract class for global variable `Keychain` */
declare class AbsKeychain<S extends KeychainState = KeychainState> extends ScriptableVariable<S> implements Keychain {
    static readonly identifier = "Keychain";
    static get instance(): AbsKeychain<KeychainState>;
    contains(key: string): boolean;
    set(key: string, value: string): void;
    get(key: string): string;
    remove(key: string): void;
}
/** Properties interface for global variable `Location` */
interface LocationState {
}
/** Type definition for global variable `Location` */
type Location = typeof Location;
/** Abstract class for global variable `Location` */
declare class AbsLocation<S extends LocationState = LocationState> extends ScriptableVariable<S> implements Location {
    static readonly identifier = "Location";
    static get instance(): AbsLocation<LocationState>;
    current(): Promise<Location.CurrentLocation>;
    setAccuracyToBest(): void;
    setAccuracyToTenMeters(): void;
    setAccuracyToHundredMeters(): void;
    setAccuracyToKilometer(): void;
    setAccuracyToThreeKilometers(): void;
    reverseGeocode(latitude: number, longitude: number, locale?: string): Promise<Location.GeocodeSummary[]>;
}
/** Properties interface for global variable `module` */
interface ModuleState {
    filename: string;
    exports: unknown;
}
/** Type definition for global variable `module` */
type Module = typeof module;
/** Abstract class for global variable `module` */
declare class AbsModule<S extends ModuleState = ModuleState> extends ScriptableVariable<S> implements Module {
    static readonly identifier = "module";
    static get instance(): AbsModule<ModuleState>;
    get filename(): string;
    set filename(value: string);
    get exports(): any;
    set exports(value: any);
}
/** Properties interface for global variable `Pasteboard` */
interface PasteboardState {
}
/** Type definition for global variable `Pasteboard` */
type Pasteboard = typeof Pasteboard;
/** Abstract class for global variable `Pasteboard` */
declare class AbsPasteboard<S extends PasteboardState = PasteboardState> extends ScriptableVariable<S> implements Pasteboard {
    static readonly identifier = "Pasteboard";
    static get instance(): AbsPasteboard<PasteboardState>;
    copy(string: string): void;
    paste(): string;
    copyString(string: string): void;
    pasteString(): string;
    copyImage(image: Image): void;
    pasteImage(): Image;
}
/** Properties interface for global variable `Photos` */
interface PhotosState {
}
/** Type definition for global variable `Photos` */
type Photos = typeof Photos;
/** Abstract class for global variable `Photos` */
declare class AbsPhotos<S extends PhotosState = PhotosState> extends ScriptableVariable<S> implements Photos {
    static readonly identifier = "Photos";
    static get instance(): AbsPhotos<PhotosState>;
    fromLibrary(): Promise<Image>;
    fromCamera(): Promise<Image>;
    latestPhoto(): Promise<Image>;
    latestPhotos(count: number): Promise<Image[]>;
    latestScreenshot(): Promise<Image>;
    latestScreenshots(count: number): Promise<Image[]>;
    removeLatestPhoto(): void;
    removeLatestPhotos(count: number): void;
    removeLatestScreenshot(): void;
    removeLatestScreenshots(count: number): void;
    save(image: Image): void;
}
/** Properties interface for global variable `QuickLook` */
interface QuickLookState {
}
/** Type definition for global variable `QuickLook` */
type QuickLook = typeof QuickLook;
/** Abstract class for global variable `QuickLook` */
declare class AbsQuickLook<S extends QuickLookState = QuickLookState> extends ScriptableVariable<S> implements QuickLook {
    static readonly identifier = "QuickLook";
    static get instance(): AbsQuickLook<QuickLookState>;
    present(item: any, fullscreen?: boolean): Promise<void>;
}
/** Properties interface for global variable `Safari` */
interface SafariState {
}
/** Type definition for global variable `Safari` */
type Safari = typeof Safari;
/** Abstract class for global variable `Safari` */
declare class AbsSafari<S extends SafariState = SafariState> extends ScriptableVariable<S> implements Safari {
    static readonly identifier = "Safari";
    static get instance(): AbsSafari<SafariState>;
    openInApp(url: string, fullscreen?: boolean): Promise<void>;
    open(url: string): void;
}
/** Properties interface for global variable `Script` */
interface ScriptState {
}
/** Type definition for global variable `Script` */
type Script = typeof Script;
/** Abstract class for global variable `Script` */
declare class AbsScript<S extends ScriptState = ScriptState> extends ScriptableVariable<S> implements Script {
    static readonly identifier = "Script";
    static get instance(): AbsScript<ScriptState>;
    name(): string;
    complete(): void;
    setShortcutOutput(value: any): void;
    setWidget(widget: any): void;
}
/** Properties interface for global variable `ShareSheet` */
interface ShareSheetState {
}
/** Type definition for global variable `ShareSheet` */
type ShareSheet = typeof ShareSheet;
/** Abstract class for global variable `ShareSheet` */
declare class AbsShareSheet<S extends ShareSheetState = ShareSheetState> extends ScriptableVariable<S> implements ShareSheet {
    static readonly identifier = "ShareSheet";
    static get instance(): AbsShareSheet<ShareSheetState>;
    present(activityItems: readonly any[]): Promise<ShareSheet.ShareSheetResult>;
}
/** Properties interface for global variable `Speech` */
interface SpeechState {
}
/** Type definition for global variable `Speech` */
type Speech = typeof Speech;
/** Abstract class for global variable `Speech` */
declare class AbsSpeech<S extends SpeechState = SpeechState> extends ScriptableVariable<S> implements Speech {
    static readonly identifier = "Speech";
    static get instance(): AbsSpeech<SpeechState>;
    speak(text: string): void;
}
/** Properties interface for global variable `URLScheme` */
interface URLSchemeState {
}
/** Type definition for global variable `URLScheme` */
type URLScheme = typeof URLScheme;
/** Abstract class for global variable `URLScheme` */
declare class AbsURLScheme<S extends URLSchemeState = URLSchemeState> extends ScriptableVariable<S> implements URLScheme {
    static readonly identifier = "URLScheme";
    static get instance(): AbsURLScheme<URLSchemeState>;
    forOpeningScript(): string;
    forOpeningScriptSettings(): string;
    forRunningScript(): string;
}
/** Properties interface for global variable `UUID` */
interface UUIDState {
}
/** Type definition for global variable `UUID` */
type UUID = typeof UUID;
/** Abstract class for global variable `UUID` */
declare class AbsUUID<S extends UUIDState = UUIDState> extends ScriptableVariable<S> implements UUID {
    static readonly identifier = "UUID";
    static get instance(): AbsUUID<UUIDState>;
    string(): string;
}
declare const GLOBAL_CLASS_NAMES: readonly ["Alert", "Calendar", "CalendarEvent", "CallbackURL", "Color", "Contact", "ContactsContainer", "ContactsGroup", "Data", "DateFormatter", "DatePicker", "DrawContext", "FileManager", "Font", "Image", "LinearGradient", "ListWidget", "Mail", "Message", "Notification", "Path", "Point", "Rect", "RecurrenceRule", "RelativeDateTimeFormatter", "Reminder", "Request", "SFSymbol", "Size", "TextField", "Timer", "UITable", "UITableCell", "UITableRow", "WebView", "WidgetDate", "WidgetImage", "WidgetSpacer", "WidgetStack", "WidgetText", "XMLParser"];
declare const GLOBAL_VAR_NAMES: readonly ["args", "config", "console", "Device", "Dictation", "DocumentPicker", "Keychain", "Location", "module", "Pasteboard", "Photos", "QuickLook", "Safari", "Script", "ShareSheet", "Speech", "URLScheme", "UUID"];
type GlobalClassName = typeof GLOBAL_CLASS_NAMES[number];
type GlobalVarName = typeof GLOBAL_VAR_NAMES[number];

export { AbsAlert, AbsArgs, AbsCalendar, AbsCalendarEvent, AbsCallbackURL, AbsColor, AbsConfig, AbsConsole, AbsContact, AbsContactsContainer, AbsContactsGroup, AbsData, AbsDateFormatter, AbsDatePicker, AbsDevice, AbsDictation, AbsDocumentPicker, AbsDrawContext, AbsFileManager, AbsFont, AbsImage, AbsKeychain, AbsLinearGradient, AbsListWidget, AbsLocation, AbsMail, AbsMessage, AbsModule, AbsNotification, AbsPasteboard, AbsPath, AbsPhotos, AbsPoint, AbsQuickLook, AbsRect, AbsRecurrenceRule, AbsRelativeDateTimeFormatter, AbsReminder, AbsRequest, AbsSFSymbol, AbsSafari, AbsScript, AbsShareSheet, AbsSize, AbsSpeech, AbsTextField, AbsTimer, AbsUITable, AbsUITableCell, AbsUITableRow, AbsURLScheme, AbsUUID, AbsWebView, AbsWidgetDate, AbsWidgetImage, AbsWidgetSpacer, AbsWidgetStack, AbsWidgetText, AbsXMLParser, type AlertState, type Args, type ArgsState, type CalendarEventState, type CalendarState, type CallbackURLState, type ColorState, type Config, type ConfigState, type Console, type ConsoleState, type ContactState, type ContactsContainerState, type ContactsGroupState, type DataState, type DateFormatterState, type DatePickerState, type Device, type DeviceState, type Dictation, type DictationState, type DocumentPicker, type DocumentPickerState, type DrawContextState, type FileManagerState, type FontState, GLOBAL_CLASS_NAMES, GLOBAL_VAR_NAMES, type GlobalClassName, type GlobalVarName, type ImageState, type Keychain, type KeychainState, type LinearGradientState, type ListWidgetState, type Location, type LocationState, type MailState, type MessageState, type Module, type ModuleState, type NotificationState, type Pasteboard, type PasteboardState, type PathState, type Photos, type PhotosState, type PointState, type QuickLook, type QuickLookState, type RectState, type RecurrenceRuleState, type RelativeDateTimeFormatterState, type ReminderState, type RequestState, type SFSymbolState, type Safari, type SafariState, type Script, type ScriptState, ScriptableBase, ScriptableClass, type ScriptableConstructor, ScriptableVariable, type ShareSheet, type ShareSheetState, type SizeState, type Speech, type SpeechState, type TextFieldState, type TimerState, type UITableCellState, type UITableRowState, type UITableState, type URLScheme, type URLSchemeState, type UUID, type UUIDState, type WebViewState, type WidgetDateState, type WidgetImageState, type WidgetSpacerState, type WidgetStackState, type WidgetTextState, type XMLParserState };
